{$N+}
UNIT plard14;

{
version 1.4d TP7 compatible (25 Jan 2000)
author: Franco Milani
email:  nadir@solaris.polarhome.com
        astlab@inwind.it
web sites:
http://www.polarhome.com/~franco
http://www.polarhome.com:723/~nadir/software
http://spazioinwind.libero.it/frm/software

Source released under the terms of the GNU General Public License
v. 2 as published by the Free Software Foundation.

This unit evaluates the ecliptic heliocentric spherical coordinates
of planets and earth, the velocity components of the earth relative
to the sun and the geocentric coordinates of the moon.
All the coordinates are geometric, and are relative to the equinox
J2000, except those of the moon which are referred to the mean
equinox and ecliptic of date.
This version reads the series coefficients from the file tabplar.ttb
to save memory. The procedure pla_getdatamem must be called first,
it allocates the arrays and loads the coefficients. No checks are
performed so, if necessary, the user must control in his program
that the file tabplar.ttb is available and regularly loaded.
The procedures pos_mer, pos_ven, pos_ear, pos_moo, pos_mar, pos_jup,
pos_sat, pos_ura, pos_nep, pos_plu return longitude and latitude in
radians and distance in AU, vel_ear returns the earth's velocity
components in radians/day and AU/day, at selected TDB Julian dates j.
The memory may be deallocated by using the procedure pla_disposemem.
Valid date ranges are: from 3000 B.C. to 3000 A.D. for the outer
planets, from 2000 B.C. to 6000 A.D. for the earth, and from 1350 B.C.
to 3000 A.D. for the inner planets and moon.
For planets and moon the unit uses the Steve Moshier's plan404
coefficients. References and notes may be found in the plan404 sources
at the Moshier's software site (http://moshier.ne.mediaone.net/index.html).
The earth's coefficients are taken from the VSOP87B.ear file located at
Bureau Des Longitudes site (ftp://ftp.bdl.fr/pub/ephem/planets/vsop87).
The file precis.txt contains the computed deviations from JPL's DE404
and DE405 ephemerides. The DE405 files are available at the Jet Propulsion
Laboratory site (ftp://navigator.jpl.nasa.gov/pub/ephem).
}

INTERFACE

PROCEDURE pla_getdatamem;                          {loads the data}
PROCEDURE pla_disposemem;                          {deallocates memory}
PROCEDURE pos_mer (j: double; var a,b,c: double);  {Mercury coordinates}
PROCEDURE pos_ven (j: double; var a,b,c: double);  {Venus coordinates}
PROCEDURE pos_ear (j: double; var a,b,c: double);  {Earth coordinates}
PROCEDURE vel_ear (j: double; var a,b,c: double);  {Earth velocity}
PROCEDURE pos_moo (j: double; var a,b,c: double);  {Moon coordinates}
PROCEDURE pos_mar (j: double; var a,b,c: double);  {Mars coordinates}
PROCEDURE pos_jup (j: double; var a,b,c: double);  {Jupiter coordinates}
PROCEDURE pos_sat (j: double; var a,b,c: double);  {Saturn coordinates}
PROCEDURE pos_ura (j: double; var a,b,c: double);  {Uranus coordinates}
PROCEDURE pos_nep (j: double; var a,b,c: double);  {Neptune coordinates}
PROCEDURE pos_plu (j: double; var a,b,c: double);  {Pluto coordinates}

IMPLEMENTATION

CONST

merargs: array[0..746] of shortint =
( 0,  3,  3,  1,  1,-10,  3, 11,  4,  0,  2,  2,  5, -5,  6,  2,  3,  5,  1,
-14,  2,  2,  3,  1,  3,  1,  1, -5,  2,  4,  3,  0,  1,  1,  6,  0,  1,  2,
  6,  0,  3,  2,  1, -7,  2,  3,  3,  0,  1,  1,  5,  2,  2,  1,  1, -4,  3,
  2,  1,  2,  5,  2,  2,  2,  1, -5,  2,  2,  1,  3,  5,  0,  2,  4,  1,-10,
  2,  1,  2,  3,  1, -8,  2,  0,  2,  1,  1, -3,  2,  2,  2,  1,  1, -2,  2,
  2,  1,  1,  3,  0,  2,  3,  1, -7,  2,  1,  2,  1,  1, -3,  3,  0,  1,  1,
  2,  0,  2,  2,  1, -4,  2,  1,  2,  4,  1, -9,  2,  0,  1,  2,  3,  0,  2,
  1,  1, -2,  3,  0,  2,  1,  1, -4,  2,  0,  2,  1,  1, -1,  2,  0,  2,  3,
  1, -6,  2,  0,  1,  3,  3,  0,  2,  2,  1, -7,  2,  0,  2,  1,  1, -2,  4,
  0,  2,  1,  1, -1,  3,  0,  1,  2,  2,  2,  2,  2,  1, -3,  2,  2,  2,  4,
  1, -8,  2,  0,  2,  3,  1,-10,  2,  0,  2,  1,  1, -4,  5,  0,  2,  1,  1,
 -3,  5,  2,  2,  1,  1, -5,  2,  2,  2,  1,  1, -5,  6,  0,  2,  1,  1, -2,
  5,  1,  3,  1,  1, -4,  5,  5,  6,  0,  1,  4,  3,  0,  2,  1,  1, -3,  6,
  1,  2,  1,  1, -1,  5,  0,  2,  1,  1, -2,  6,  0,  2,  1,  1, -1,  6,  0,
  2,  1,  1, -2,  7,  0,  2,  1,  1, -1,  7,  0,  3,  4,  1,-14,  2,  2,  3,
  0,  3,  1,  1,  2,  5, -5,  6,  0,  1,  1,  1,  6,  3,  2,  1,-10,  3, 11,
  4,  0,  3,  1,  1, -2,  5,  5,  6,  0,  3,  6,  1,-14,  2,  2,  3,  0,  2,
  1,  1,  1,  6,  0,  2,  1,  1,  2,  6,  0,  2,  1,  1,  1,  5,  1,  2,  2,
  1, -4,  3,  1,  2,  1,  1,  2,  5,  0,  2,  3,  1, -5,  2,  2,  2,  1,  1,
  3,  5,  0,  2,  5,  1,-10,  2,  0,  1,  3,  2,  0,  2,  2,  1, -2,  2,  0,
  2,  1,  1,  1,  3,  0,  2,  4,  1, -7,  2,  0,  2,  2,  1, -3,  3,  0,  2,
  1,  1,  1,  2,  0,  2,  3,  1, -4,  2,  0,  2,  5,  1, -9,  2,  0,  2,  1,
  1,  2,  3,  0,  2,  2,  1, -2,  3,  0,  1,  4,  2,  0,  2,  2,  1, -1,  2,
  0,  2,  4,  1, -6,  2,  0,  2,  2,  1, -2,  4,  0,  2,  2,  1, -1,  3,  0,
  2,  1,  1,  2,  2,  1,  2,  3,  1, -3,  2,  0,  2,  5,  1, -8,  2,  0,  2,
  2,  1, -3,  5,  0,  1,  5,  2,  1,  2,  2,  1, -2,  5,  0,  2,  1,  1,  4,
  3,  0,  2,  2,  1, -3,  6,  0,  2,  2,  1, -1,  5,  0,  2,  2,  1, -2,  6,
  0,  1,  2,  1,  4,  2,  2,  1,  1,  5,  0,  2,  3,  1, -4,  3,  0,  2,  2,
  1,  2,  5,  0,  2,  4,  1, -5,  2,  2,  2,  1,  1,  3,  2,  0,  2,  3,  1,
 -2,  2,  1,  2,  3,  1, -3,  3,  0,  2,  2,  1,  1,  2,  0,  2,  4,  1, -4,
  2,  0,  2,  3,  1, -2,  3,  0,  2,  3,  1, -1,  2,  0,  2,  3,  1, -1,  3,
  0,  2,  2,  1,  2,  2,  0,  2,  4,  1, -3,  2,  0,  2,  3,  1, -3,  5,  0,
  2,  1,  1,  5,  2,  1,  2,  3,  1, -2,  5,  0,  2,  3,  1, -1,  5,  0,  2,
  3,  1, -2,  6,  0,  1,  3,  1,  3,  2,  4,  1, -4,  3,  0,  2,  5,  1, -5,
  2,  0,  2,  4,  1, -2,  2,  0,  2,  5,  1, -4,  2,  0,  2,  4,  1, -2,  3,
  0,  2,  5,  1, -3,  2,  0,  2,  2,  1,  5,  2,  0,  2,  4,  1, -2,  5,  0,
  2,  4,  1, -1,  5,  0,  1,  4,  1,  3,  2,  6,  1, -5,  2,  1,  2,  5,  1,
 -2,  2,  0,  2,  5,  1, -2,  5,  0,  1,  5,  1,  3,  2,  7,  1, -5,  2,  0,
  1,  6,  1,  3,  1,  7,  1,  3,  1,  8,  1,  2,  1,  9,  1,  2,  1, 10,  1,
  1,  1, 11,  1,  0, -1);

venargs: array[0..638] of shortint =
( 0,  3,  2,  2,  5, -5,  6,  0,  3,  2,  2,  1,  3, -8,  4,  0,  3,  5,  1,
-14,  2,  2,  3,  0,  3,  3,  2, -7,  3,  4,  4,  0,  2,  8,  2,-13,  3,  2,
  3,  6,  2,-10,  3,  3,  5,  0,  1,  1,  7,  0,  2,  1,  5, -2,  6,  0,  2,
  1,  2, -3,  4,  2,  2,  2,  5, -4,  6,  1,  1,  1,  6,  0,  3,  3,  2, -5,
  3,  1,  5,  0,  3,  3,  2, -5,  3,  2,  5,  0,  2,  1,  5, -1,  6,  0,  2,
  2,  2, -6,  4,  1,  2,  2,  5, -3,  6,  0,  1,  2,  6,  0,  2,  3,  5, -5,
  6,  0,  1,  1,  5,  1,  2,  2,  5, -2,  6,  0,  2,  3,  2, -5,  3,  2,  2,
  5,  2, -8,  3,  1,  1,  2,  5,  0,  2,  2,  1, -5,  2,  1,  2,  6,  2,-10,
  3,  0,  2,  2,  2, -3,  3,  2,  2,  1,  2, -2,  3,  1,  2,  4,  2, -7,  3,
  0,  2,  4,  2, -6,  3,  0,  1,  1,  4,  0,  2,  1,  2, -2,  4,  0,  2,  2,
  2, -5,  4,  0,  2,  1,  2, -1,  3,  0,  2,  1,  1, -3,  2,  0,  2,  2,  2,
 -4,  3,  0,  2,  6,  2, -9,  3,  0,  2,  3,  2, -4,  3,  2,  2,  1,  1, -2,
  2,  0,  1,  1,  3,  0,  2,  1,  2, -1,  4,  0,  2,  2,  2, -4,  4,  0,  2,
  5,  2, -7,  3,  0,  2,  2,  2, -2,  3,  0,  2,  1,  2, -3,  5,  0,  2,  1,
  2, -3,  3,  0,  2,  7,  2,-10,  3,  0,  2,  1,  2, -2,  5,  1,  2,  4,  2,
 -5,  3,  1,  3,  1,  2,  1,  5, -5,  6,  0,  2,  1,  2, -1,  5,  0,  3,  1,
  2, -3,  5,  5,  6,  0,  2,  1,  2, -2,  6,  0,  2,  1,  2, -1,  6,  0,  1,
  3,  4,  0,  2,  7,  2,-13,  3,  0,  3,  1,  2,  2,  5, -5,  6,  1,  1,  1,
  2,  5,  2,  9,  2,-13,  3,  0,  3,  1,  2,  1,  5, -2,  6,  0,  2,  2,  2,
 -3,  4,  2,  2,  3,  2, -6,  4,  0,  2,  1,  2,  1,  5,  0,  2,  2,  2, -5,
  3,  0,  2,  6,  2, -8,  3,  0,  2,  2,  1, -4,  2,  0,  2,  3,  2, -3,  3,
  0,  1,  2,  3,  0,  2,  3,  2, -7,  3,  0,  2,  5,  2, -6,  3,  1,  2,  2,
  2, -2,  4,  0,  2,  3,  2, -5,  4,  0,  2,  2,  2, -1,  3,  0,  2,  7,  2,
 -9,  3,  0,  2,  4,  2, -4,  3,  0,  2,  1,  2,  1,  3,  0,  2,  3,  2, -4,
  4,  0,  2,  6,  2, -7,  3,  0,  2,  3,  2, -2,  3,  0,  2,  2,  2, -4,  5,
  0,  2,  2,  2, -3,  5,  0,  2,  2,  2, -2,  5,  0,  2,  5,  2, -5,  3,  0,
  2,  2,  2, -3,  6,  0,  2,  2,  2, -1,  5,  0,  2,  2,  2, -2,  6,  0,  1,
  2,  2,  3,  2,  2,  2,  1,  5,  0,  2,  7,  2, -8,  3,  0,  2,  2,  1, -3,
  2,  0,  2,  4,  2, -3,  3,  0,  2,  6,  2, -6,  3,  0,  2,  3,  2, -1,  3,
  0,  2,  8,  2, -9,  3,  0,  2,  5,  2, -4,  3,  0,  2,  7,  2, -7,  3,  0,
  2,  4,  2, -2,  3,  0,  2,  3,  2, -4,  5,  0,  2,  3,  2, -3,  5,  0,  2,
  9,  2,-10,  3,  0,  2,  3,  2, -2,  5,  0,  1,  3,  2,  2,  2,  8,  2, -8,
  3,  0,  2,  5,  2, -3,  3,  0,  2,  9,  2, -9,  3,  0,  2, 10,  2,-10,  3,
  0,  1,  4,  2,  1,  2, 11,  2,-11,  3,  0, -1);

marargs: array[0..1290] of shortint =
( 0,  4,  3,  4,  3, -8,  4,  3,  5,  2,  3,  5,  2, -6,  3, -4,  4,  0,  2,
  2,  5, -5,  6,  1,  3, 12,  3,-24,  4,  9,  5,  0,  3,  2,  2,  1,  3, -8,
  4,  1,  3, 11,  3,-21,  4,  2,  5,  0,  3,  3,  2, -7,  3,  4,  4,  0,  3,
  7,  3,-13,  4, -1,  5,  1,  3,  1,  3, -2,  4,  2,  6,  0,  3,  1,  2, -8,
  3, 12,  4,  1,  3,  1,  4, -8,  5,  4,  6,  0,  3,  1,  4, -7,  5,  2,  6,
  0,  3,  1,  4, -9,  5,  7,  6,  0,  1,  1,  7,  0,  2,  1,  5, -2,  6,  0,
  3,  1,  3, -2,  4,  1,  5,  0,  3,  3,  3, -6,  4,  2,  5,  1,  3, 12,  3,
-23,  4,  3,  5,  0,  2,  8,  3,-15,  4,  3,  2,  1,  4, -6,  5,  2,  3,  2,
  2, -7,  3,  7,  4,  0,  2,  1,  2, -3,  4,  2,  2,  2,  5, -4,  6,  0,  1,
  1,  6,  1,  2,  9,  3,-17,  4,  2,  3,  2,  3, -4,  4,  2,  5,  0,  3,  2,
  3, -4,  4,  1,  5,  0,  2,  1,  5, -1,  6,  0,  2,  2,  2, -6,  4,  2,  2,
  1,  3, -2,  4,  2,  2,  2,  5, -3,  6,  0,  1,  2,  6,  1,  2,  3,  5, -5,
  6,  1,  1,  1,  5,  2,  3,  4,  3, -8,  4,  2,  5,  0,  2,  1,  5, -5,  6,
  0,  2,  7,  3,-13,  4,  2,  2,  3,  2, -9,  4,  0,  2,  2,  5, -2,  6,  0,
  1,  3,  6,  0,  2,  1,  4, -5,  5,  0,  2,  2,  3, -4,  4,  2,  2,  6,  3,
-11,  4,  2,  2,  4,  5, -5,  6,  0,  1,  2,  5,  2,  3,  1,  4, -3,  5, -3,
  6,  0,  2,  3,  3, -6,  4,  2,  2,  1,  4, -4,  5,  1,  2,  5,  3, -9,  4,
  2,  1,  3,  5,  1,  2,  4,  3, -8,  4,  2,  3,  1,  4, -4,  5,  2,  6,  0,
  3,  1,  4, -1,  5, -5,  6,  0,  2,  4,  3, -7,  4,  2,  2,  1,  4, -3,  5,
  2,  3,  1,  4, -5,  5,  5,  6,  1,  3,  1,  4, -4,  5,  3,  6,  0,  3,  1,
  4, -3,  5,  1,  6,  0,  2,  5,  3,-10,  4,  1,  1,  4,  5,  0,  2,  3,  3,
 -5,  4,  2,  3,  1,  4, -3,  5,  2,  6,  0,  2,  1,  4, -5,  6,  2,  2,  1,
  4, -2,  5,  2,  3,  1,  4, -4,  5,  5,  6,  1,  2,  6,  3,-12,  4,  1,  2,
  1,  4, -4,  6,  0,  2,  2,  3, -3,  4,  2,  2, 10,  3,-18,  4,  0,  2,  1,
  4, -3,  6,  1,  3,  1,  4, -2,  5,  2,  6,  0,  2,  7,  3,-14,  4,  1,  3,
  1,  4,  1,  5, -5,  6,  1,  2,  1,  4, -1,  5,  0,  3,  1,  4, -3,  5,  5,
  6,  1,  3,  1,  4,  2,  5, -7,  6,  1,  2,  1,  4, -2,  6,  2,  3,  1,  4,
 -2,  5,  3,  6,  0,  2,  1,  3, -1,  4,  0,  2,  2,  2, -7,  4,  1,  2,  9,
  3,-16,  4,  2,  2,  1,  4, -3,  7,  0,  2,  1,  4, -1,  6,  0,  3,  1,  4,
 -2,  5,  4,  6,  1,  2,  1,  2, -4,  4,  2,  2,  8,  3,-16,  4,  2,  2,  1,
  4, -2,  7,  0,  3,  3,  3, -5,  4,  2,  5,  0,  3,  1,  4,  1,  5, -3,  6,
  0,  2,  1,  4, -2,  8,  0,  2,  1,  4, -1,  7,  0,  2,  1,  4, -1,  8,  0,
  3,  3,  2, -7,  3,  3,  4,  0,  3,  2,  2,  1,  3, -7,  4,  0,  3,  1,  4,
  1,  6, -3,  7,  0,  3,  1,  4,  2,  5, -5,  6,  1,  3,  4,  3, -7,  4,  3,
  5,  1,  1,  1,  4,  5,  3,  4,  3, -9,  4,  3,  5,  1,  3,  1,  4, -2,  5,
  5,  6,  0,  3,  3,  2, -7,  3,  5,  4,  0,  3,  1,  3, -1,  4,  2,  6,  0,
  3,  1,  4,  1,  5, -2,  6,  0,  3,  3,  3, -7,  4,  2,  5,  0,  2,  8,  3,
-14,  4,  1,  2,  1,  2, -2,  4,  1,  2,  1,  4,  1,  6,  1,  2,  9,  3,-18,
  4,  1,  2,  2,  2, -5,  4,  1,  2,  1,  3, -3,  4,  2,  2,  1,  4,  2,  6,
  0,  2,  1,  4,  1,  5,  1,  3,  4,  3, -9,  4,  2,  5,  1,  2,  7,  3,-12,
  4,  1,  2,  2,  4, -5,  5,  0,  2,  2,  3, -5,  4,  2,  2,  6,  3,-10,  4,
  1,  2,  1,  4,  2,  5,  1,  3,  2,  4, -5,  5,  2,  6,  0,  2,  3,  3, -7,
  4,  1,  2,  2,  4, -4,  5,  0,  2,  5,  3, -8,  4,  1,  2,  1,  4,  3,  5,
  0,  3,  2,  4, -4,  5,  2,  6,  0,  3,  2,  4, -1,  5, -5,  6,  0,  2,  4,
  3, -6,  4,  1,  2,  2,  4, -3,  5,  0,  3,  2,  4, -5,  5,  5,  6,  1,  3,
  2,  4, -4,  5,  3,  6,  0,  2,  3,  3, -4,  4,  1,  2,  2,  4, -5,  6,  2,
  2,  2,  4, -2,  5,  1,  3,  2,  4, -4,  5,  5,  6,  1,  2,  2,  4, -4,  6,
  0,  2,  2,  3, -2,  4,  0,  2,  2,  4, -3,  6,  1,  2,  2,  4, -1,  5,  1,
  2,  2,  4, -2,  6,  0,  1,  1,  3,  1,  2,  2,  4, -1,  6,  0,  2,  1,  2,
 -5,  4,  1,  2,  8,  3,-17,  4,  1,  3,  2,  4,  2,  5, -5,  6,  1,  3,  4,
  3, -6,  4,  3,  5,  1,  3, 10,  3,-17,  4,  3,  6,  0,  1,  2,  4,  4,  3,
  4,  3,-10,  4,  3,  5,  1,  2,  8,  3,-13,  4,  0,  2,  1,  2, -1,  4,  0,
  2,  2,  4,  1,  6,  0,  2,  2,  2, -4,  4,  0,  2,  1,  3, -4,  4,  1,  2,
  2,  4,  1,  5,  0,  2,  7,  3,-11,  4,  0,  2,  3,  4, -5,  5,  0,  2,  2,
  3, -6,  4,  1,  2,  6,  3, -9,  4,  0,  2,  2,  4,  2,  5,  0,  2,  3,  4,
 -4,  5,  0,  2,  5,  3, -7,  4,  0,  2,  4,  3, -5,  4,  1,  2,  3,  4, -3,
  5,  1,  2,  3,  3, -3,  4,  0,  2,  3,  4, -2,  5,  2,  3,  3,  4, -4,  5,
  5,  6,  0,  2,  2,  3, -1,  4,  0,  2,  3,  4, -3,  6,  0,  2,  3,  4, -1,
  5,  1,  2,  3,  4, -2,  6,  0,  2,  1,  3,  1,  4,  1,  2,  3,  4, -1,  6,
  0,  3,  4,  3, -5,  4,  3,  5,  0,  1,  3,  4,  3,  3,  4,  3,-11,  4,  3,
  5,  0,  1,  1,  2,  0,  2,  2,  2, -3,  4,  0,  2,  1,  3, -5,  4,  0,  2,
  4,  4, -5,  5,  0,  2,  6,  3, -8,  4,  0,  2,  4,  4, -4,  5,  0,  2,  5,
  3, -6,  4,  0,  2,  4,  3, -4,  4,  0,  2,  4,  4, -3,  5,  1,  3,  6,  3,
 -8,  4,  2,  5,  0,  2,  3,  3, -2,  4,  0,  2,  4,  4, -2,  5,  1,  2,  4,
  4, -1,  5,  0,  2,  1,  3,  2,  4,  0,  1,  4,  4,  3,  2,  2,  2, -2,  4,
  0,  2,  7,  3, -9,  4,  0,  2,  5,  4, -5,  5,  0,  2,  6,  3, -7,  4,  0,
  2,  5,  4, -4,  5,  0,  2,  5,  3, -5,  4,  0,  2,  5,  4, -3,  5,  0,  2,
  5,  4, -2,  5,  0,  1,  5,  4,  3,  1,  6,  4,  2,  1,  7,  4,  0, -1);

jupargs: array[0..904] of shortint =
( 0,  6,  3,  2,  5, -6,  6,  3,  7,  0,  2,  2,  5, -5,  6,  6,  3,  1,  5,
 -2,  6, -3,  8,  0,  2,  4,  5,-10,  6,  4,  3,  2,  5, -4,  6, -3,  7,  1,
  3,  3,  5,-10,  6,  7,  7,  0,  2,  6,  5,-15,  6,  0,  3,  1,  5, -4,  6,
  4,  7,  0,  3,  3,  5, -8,  6,  2,  7,  0,  3,  1,  5, -3,  6,  1,  7,  0,
  3,  1,  5, -3,  6,  2,  7,  0,  1,  1,  7,  1,  2,  5,  5,-12,  6,  0,  3,
  2,  5, -7,  6,  7,  7,  0,  3,  1,  5, -1,  6, -3,  7,  0,  2,  3,  5, -7,
  6,  3,  3,  1,  5, -4,  6,  3,  7,  0,  2,  1,  5, -2,  6,  3,  3,  3,  5,
 -8,  6,  3,  7,  0,  2,  1,  5, -3,  6,  3,  3,  1,  5, -3,  6,  3,  7,  0,
  2,  3,  5, -8,  6,  2,  3,  2,  5, -5,  6,  2,  7,  0,  1,  2,  7,  0,  2,
  4,  5, -9,  6,  3,  2,  2,  5, -4,  6,  4,  1,  1,  6,  2,  3,  2,  5, -5,
  6,  3,  7,  0,  2,  2,  5, -6,  6,  2,  2,  5,  5,-11,  6,  1,  3,  1,  5,
 -2,  7, -2,  8,  0,  2,  1,  5, -3,  7,  1,  2,  3,  5, -6,  6,  3,  2,  1,
  5, -1,  6,  2,  2,  1,  5, -4,  6,  2,  2,  3,  5, -9,  6,  0,  3,  2,  5,
 -4,  6,  2,  7,  0,  2,  1,  5, -2,  7,  1,  2,  6,  5,-13,  6,  0,  3,  2,
  5, -2,  6, -3,  7,  0,  2,  4,  5, -8,  6,  3,  2,  3,  6, -3,  7,  0,  3,
  6,  5,-14,  6,  3,  7,  0,  3,  1,  5, -2,  7,  1,  8,  0,  2,  2,  5, -3,
  6,  2,  3,  1,  5, -4,  7,  5,  8,  0,  3,  2,  5, -8,  6,  3,  7,  0,  3,
  4,  5, -9,  6,  3,  7,  0,  1,  2,  6,  3,  3,  2,  5, -4,  6,  3,  7,  0,
  2,  2,  5, -7,  6,  2,  2,  1,  5, -2,  8,  0,  2,  1,  5, -1,  7,  0,  3,
  3,  5, -6,  6,  2,  7,  0,  3,  4,  5, -8,  6,  2,  8,  0,  2,  1,  5, -1,
  8,  0,  3,  2,  5, -3,  6,  1,  7,  0,  2,  7,  5,-15,  6,  2,  3,  3,  5,
 -4,  6, -3,  7,  1,  2,  5,  5,-10,  6,  4,  3,  1,  5,  1,  6, -3,  7,  1,
  3,  7,  5,-16,  6,  3,  7,  0,  2,  3,  5, -5,  6,  4,  3,  1,  5, -6,  6,
  3,  7,  0,  3,  5,  5,-11,  6,  3,  7,  0,  1,  1,  5,  5,  3,  3,  5,-11,
  6,  3,  7,  0,  3,  3,  5, -6,  6,  3,  7,  0,  2,  2,  5, -7,  7,  0,  2,
  1,  5, -5,  6,  3,  3,  1,  5, -1,  6,  3,  7,  0,  2,  3,  5,-10,  6,  3,
  3,  2,  5, -3,  6,  2,  7,  0,  2,  1,  5,  1,  7,  0,  3,  2,  5, -1,  6,
 -3,  7,  0,  2,  4,  5, -7,  6,  3,  2,  4,  6, -3,  7,  0,  2,  2,  5, -2,
  6,  4,  3,  4,  5, -8,  6,  3,  7,  0,  1,  3,  6,  3,  3,  2,  5, -3,  6,
  3,  7,  0,  2,  5,  5, -9,  6,  3,  2,  3,  5, -4,  6,  2,  2,  1,  5,  1,
  6,  2,  2,  2,  5, -4,  7,  0,  2,  6,  5,-11,  6,  2,  2,  2,  5, -3,  7,
  0,  2,  4,  5, -6,  6,  2,  2,  2,  5, -1,  6,  2,  1,  4,  6,  1,  2,  2,
  5, -2,  7,  0,  2,  5,  5, -8,  6,  2,  2,  3,  5, -3,  6,  2,  2,  1,  5,
  2,  6,  2,  2,  2,  5, -2,  8,  0,  2,  2,  5, -1,  7,  0,  2,  6,  5,-10,
  6,  3,  2,  4,  5, -5,  6,  3,  2,  6,  6, -3,  7,  0,  1,  2,  5,  5,  3,
  4,  5, -6,  6,  3,  7,  0,  1,  5,  6,  4,  2,  2,  5,-10,  6,  1,  2,  5,
  5, -7,  6,  1,  2,  3,  5, -2,  6,  2,  2,  1,  5,  3,  6,  2,  2,  6,  5,
 -9,  6,  2,  2,  4,  5, -4,  6,  2,  2,  2,  5,  1,  6,  2,  2,  7,  5,-11,
  6,  0,  2,  3,  5, -3,  7,  0,  2,  5,  5, -6,  6,  2,  2,  3,  5, -1,  6,
  1,  2,  3,  5, -2,  7,  0,  2,  6,  5, -8,  6,  1,  2,  4,  5, -3,  6,  1,
  2,  2,  5,  2,  6,  0,  2,  7,  5,-10,  6,  1,  2,  5,  5, -5,  6,  2,  1,
  3,  5,  3,  2,  1,  5,  5,  6,  2,  2,  6,  5, -7,  6,  1,  2,  4,  5, -2,
  6,  1,  2,  7,  5, -9,  6,  1,  2,  5,  5, -4,  6,  0,  2,  6,  5, -6,  6,
  0,  2,  4,  5, -1,  6,  0,  2,  7,  5, -8,  6,  1,  2,  5,  5, -3,  6,  0,
  2,  8,  5,-10,  6,  0,  2,  6,  5, -5,  6,  0,  1,  4,  5,  2,  2,  7,  5,
 -7,  6,  0,  2,  5,  5, -2,  6,  0,  2,  8,  5, -9,  6,  0,  2,  7,  5, -6,
  6,  0,  2,  8,  5, -8,  6,  0,  2,  9,  5,-10,  6,  0,  1,  5,  5,  0,  2,
  9,  5, -9,  6,  0,  2,  1,  3, -1,  5,  0, -1);

satargs: array[0..1452] of shortint =
( 0,  7,  3,  2,  5, -6,  6,  3,  7,  0,  2,  2,  5, -5,  6,  5,  3,  1,  6,
 -4,  7,  2,  8,  0,  2,  1,  6, -3,  7,  0,  3,  1,  6, -2,  7, -2,  8,  0,
  2,  4,  5,-10,  6,  3,  3,  1,  5, -1,  6, -4,  7,  0,  3,  2,  5, -4,  6,
 -3,  7,  0,  3,  2,  6, -8,  7,  4,  8,  0,  3,  3,  5,-10,  6,  7,  7,  0,
  2,  6,  5,-15,  6,  0,  2,  2,  6, -6,  7,  0,  3,  1,  5, -4,  6,  4,  7,
  1,  3,  1,  5, -2,  6, -1,  7,  0,  3,  2,  5, -5,  6,  1,  8,  0,  3,  3,
  5, -8,  6,  2,  7,  0,  3,  1,  5, -3,  6,  2,  8,  0,  3,  1,  5, -3,  6,
  1,  7,  1,  1,  1,  8,  0,  3,  1,  5, -3,  6,  2,  7,  1,  3,  1,  5, -2,
  6, -2,  7,  0,  2,  2,  6, -5,  7,  1,  3,  2,  6, -6,  7,  2,  8,  0,  3,
  2,  6, -7,  7,  4,  8,  0,  3,  2,  5, -4,  6, -2,  7,  0,  3,  1,  5, -1,
  6, -5,  7,  0,  3,  2,  6, -7,  7,  5,  8,  0,  3,  1,  6, -1,  7, -2,  8,
  0,  2,  1,  6, -2,  7,  1,  3,  1,  6, -3,  7,  2,  8,  0,  3,  1,  6, -4,
  7,  4,  8,  1,  3,  2,  5, -5,  6,  2,  8,  1,  3,  2,  5, -6,  6,  2,  7,
  1,  2,  2,  7, -2,  8,  0,  1,  1,  7,  2,  2,  5,  5,-12,  6,  2,  3,  2,
  6, -5,  7,  1,  8,  0,  3,  1,  5, -1,  6, -3,  7,  0,  3,  7,  5,-18,  6,
  3,  7,  0,  2,  3,  5, -7,  6,  3,  3,  1,  6,  1,  7, -5,  8,  0,  3,  1,
  5, -4,  6,  3,  7,  0,  3,  5,  5,-13,  6,  3,  7,  0,  2,  1,  5, -2,  6,
  3,  3,  3,  5, -9,  6,  3,  7,  0,  3,  3,  5, -8,  6,  3,  7,  1,  2,  1,
  5, -3,  6,  3,  3,  5,  5,-14,  6,  3,  7,  0,  3,  1,  5, -3,  6,  3,  7,
  2,  2,  3,  6, -7,  7,  0,  2,  3,  5, -8,  6,  2,  3,  2,  5, -3,  6, -4,
  7,  1,  3,  2,  5, -8,  6,  7,  7,  0,  2,  5,  5,-13,  6,  0,  2,  2,  6,
 -4,  7,  2,  3,  2,  6, -5,  7,  2,  8,  0,  3,  2,  5, -4,  6, -1,  7,  0,
  3,  2,  5, -7,  6,  4,  7,  0,  2,  1,  6, -2,  8,  2,  2,  1,  6, -1,  7,
  0,  3,  1,  6, -2,  7,  2,  8,  0,  3,  2,  5, -5,  6,  2,  7,  0,  3,  2,
  5, -6,  6,  2,  8,  0,  3,  2,  5, -6,  6,  1,  7,  0,  2,  3,  7, -2,  8,
  0,  1,  2,  7,  1,  2,  1,  6, -1,  8,  1,  3,  1,  5, -2,  6,  1,  7,  0,
  3,  1,  5, -2,  6,  2,  8,  0,  2,  3,  6, -6,  7,  2,  2,  6,  5,-14,  6,
  0,  3,  3,  6, -7,  7,  2,  8,  0,  3,  2,  5, -3,  6, -3,  7,  1,  2,  4,
  5, -9,  6,  3,  3,  2,  6, -2,  7, -2,  8,  0,  2,  2,  6, -3,  7,  1,  3,
  2,  6, -4,  7,  2,  8,  0,  2,  2,  5, -4,  6,  3,  3,  2,  5, -7,  6,  3,
  7,  1,  3,  1,  6,  1,  7, -2,  8,  0,  1,  1,  6,  5,  3,  2,  5, -5,  6,
  3,  7,  1,  2,  2,  5, -6,  6,  3,  1,  3,  7,  3,  2,  4,  5,-11,  6,  3,
  2,  1,  5, -4,  7,  0,  3,  2,  5, -5,  6, -3,  7,  1,  2,  6,  5,-16,  6,
  0,  3,  3,  5, -7,  6,  2,  7,  0,  3,  3,  6, -4,  7, -2,  8,  0,  2,  3,
  6, -5,  7,  1,  3,  3,  6, -6,  7,  2,  8,  1,  3,  3,  6, -7,  7,  4,  8,
  0,  3,  2,  5, -3,  6, -2,  7,  2,  3,  2,  5, -8,  6,  5,  7,  0,  2,  2,
  6, -4,  8,  0,  3,  2,  6, -1,  7, -2,  8,  1,  2,  2,  6, -2,  7,  2,  3,
  2,  6, -3,  7,  2,  8,  0,  3,  2,  5, -4,  6,  1,  7,  0,  3,  2,  5, -4,
  6,  2,  8,  0,  3,  2,  5, -7,  6,  2,  7,  1,  2,  1,  6,  1,  7,  1,  2,
  5,  5,-11,  6,  2,  3,  1,  5, -2,  7, -2,  8,  0,  2,  1,  5, -3,  7,  0,
  2,  3,  5, -6,  6,  3,  3,  2,  6,  1,  7, -5,  8,  0,  2,  2,  6, -3,  8,
  1,  2,  1,  5, -1,  6,  3,  3,  2,  5, -7,  6,  3,  8,  0,  3,  3,  5, -7,
  6,  3,  7,  0,  3,  2,  5, -1,  6, -7,  7,  0,  2,  1,  5, -4,  6,  2,  3,
  1,  5, -2,  6,  3,  7,  0,  2,  4,  6, -7,  7,  0,  2,  3,  5, -9,  6,  0,
  3,  2,  5, -2,  6, -4,  7,  0,  2,  3,  6, -4,  7,  2,  3,  2,  5, -3,  6,
 -1,  7,  0,  3,  2,  5, -8,  6,  4,  7,  0,  2,  2,  6, -2,  8,  1,  2,  2,
  6, -1,  7,  0,  3,  2,  6, -2,  7,  2,  8,  1,  3,  2,  5, -4,  6,  2,  7,
  0,  3,  2,  5, -7,  6,  2,  8,  0,  3,  2,  5, -7,  6,  1,  7,  0,  2,  1,
  6,  2,  7,  0,  2,  2,  6, -1,  8,  0,  2,  4,  6, -6,  7,  1,  2,  6,  5,
-13,  6,  0,  3,  2,  5, -2,  6, -3,  7,  1,  2,  4,  5, -8,  6,  2,  3,  3,
  6, -2,  7, -2,  8,  0,  2,  3,  6, -3,  7,  0,  3,  3,  6, -4,  7,  2,  8,
  0,  2,  2,  5, -3,  6,  3,  3,  2,  5, -8,  6,  3,  7,  1,  3,  2,  6,  1,
  7, -2,  8,  0,  1,  2,  6,  5,  3,  2,  5, -4,  6,  3,  7,  2,  2,  2,  5,
 -7,  6,  3,  3,  1,  6,  4,  7, -2,  8,  0,  2,  1,  6,  3,  7,  1,  3,  1,
  6,  2,  7,  2,  8,  0,  2,  4,  5,-12,  6,  2,  2,  5,  6, -8,  7,  0,  2,
  4,  6, -5,  7,  0,  3,  2,  5, -2,  6, -2,  7,  0,  2,  3,  6, -2,  7,  1,
  3,  3,  6, -3,  7,  2,  8,  0,  2,  5,  5,-10,  6,  2,  3,  1,  5,  1,  6,
 -3,  7,  0,  2,  3,  5, -5,  6,  3,  2,  3,  6, -3,  8,  0,  1,  1,  5,  2,
  2,  1,  5, -5,  6,  2,  2,  5,  6, -7,  7,  0,  2,  4,  6, -4,  7,  2,  2,
  3,  6, -2,  8,  0,  2,  3,  6, -1,  7,  0,  2,  5,  6, -6,  7,  0,  2,  4,
  5, -7,  6,  2,  2,  4,  6, -3,  7,  2,  2,  2,  5, -2,  6,  2,  3,  2,  6,
 -9,  7,  3,  8,  0,  1,  3,  6,  4,  3,  2,  5, -3,  6,  3,  7,  1,  2,  2,
  5, -8,  6,  3,  3,  2,  6,  4,  7, -2,  8,  0,  2,  4,  5,-13,  6,  1,  2,
  6,  6, -8,  7,  1,  2,  5,  6, -5,  7,  0,  2,  4,  6, -2,  7,  0,  2,  5,
  5, -9,  6,  2,  2,  3,  5, -4,  6,  2,  2,  1,  5,  1,  6,  2,  2,  6,  5,
-11,  6,  0,  3,  6,  6, -7,  7,  2,  8,  0,  2,  4,  5, -6,  6,  2,  2,  2,
  5, -1,  6,  2,  1,  4,  6,  3,  3,  2,  5, -2,  6,  3,  7,  1,  2,  2,  5,
 -9,  6,  1,  2,  5,  5, -8,  6,  2,  2,  3,  5, -3,  6,  1,  2,  1,  5,  2,
  6,  2,  2,  6,  5,-10,  6,  1,  2,  4,  5, -5,  6,  2,  1,  2,  5,  1,  1,
  5,  6,  2,  2,  5,  5, -7,  6,  1,  2,  3,  5, -2,  6,  1,  3,  1,  5,  2,
  6,  3,  7,  0,  2,  6,  5, -9,  6,  0,  2,  4,  5, -4,  6,  2,  2,  2,  5,
  1,  6,  1,  2,  7,  5,-11,  6,  0,  2,  5,  5, -6,  6,  1,  2,  3,  5, -1,
  6,  1,  2,  6,  5, -8,  6,  1,  2,  4,  5, -3,  6,  0,  2,  5,  5, -5,  6,
  0,  1,  3,  5,  0,  2,  6,  5, -7,  6,  1,  2,  7,  5, -9,  6,  0,  2,  5,
  5, -4,  6,  0,  2,  6,  5, -6,  6,  0,  2,  7,  5, -8,  6,  0,  2,  6,  5,
 -5,  6,  0,  2,  7,  5, -7,  6,  0,  2,  8,  5, -9,  6,  0,  2,  8,  5, -8,
  6,  0,  2,  1,  3, -1,  6,  0, -1);

uraargs: array[0..1166] of shortint =
( 0,  3,  2,  1,  7, -2,  8,  0,  2,  2,  7, -4,  8,  0,  2,  3,  7, -6,  8,
  1,  2,  2,  5, -5,  6,  4,  2,  1,  6, -3,  7,  3,  3,  1,  6, -1,  7, -4,
  8,  0,  3,  2,  5, -7,  6,  6,  7,  0,  3,  2,  6, -6,  7,  1,  8,  0,  3,
  2,  6, -7,  7,  3,  8,  0,  3,  2,  6, -8,  7,  4,  8,  0,  3,  2,  6, -7,
  7,  2,  8,  0,  2,  2,  6, -6,  7,  2,  3,  1,  5, -4,  6,  4,  7,  0,  3,
  1,  6, -2,  7, -1,  8,  0,  3,  1,  6, -3,  7,  1,  8,  0,  3,  1,  6, -4,
  7,  3,  8,  1,  2,  5,  7, -9,  8,  0,  2,  4,  7, -7,  8,  0,  2,  2,  7,
 -3,  8,  6,  2,  1,  7, -3,  8,  2,  2,  2,  7, -5,  8,  0,  2,  3,  7, -7,
  8,  0,  3,  1,  6, -6,  7,  5,  8,  1,  3,  1,  6, -5,  7,  3,  8,  0,  3,
  2,  5, -8,  6,  8,  7,  0,  3,  1,  5, -4,  6,  5,  7,  0,  2,  2,  6, -5,
  7,  3,  3,  1,  6,  1,  7, -9,  8,  0,  3,  2,  5, -4,  6, -2,  7,  0,  2,
  1,  6, -4,  8,  4,  2,  1,  6, -2,  7,  4,  2,  5,  7, -8,  8,  5,  2,  3,
  7, -4,  8,  0,  1,  1,  7,  5,  2,  2,  7, -6,  8,  4,  3,  1,  6, -6,  7,
  4,  8,  0,  2,  1,  6, -4,  7,  4,  3,  2,  6, -5,  7,  1,  8,  0,  3,  2,
  6, -6,  7,  3,  8,  0,  2,  2,  6, -7,  7,  0,  3,  1,  5, -4,  6,  3,  7,
  0,  3,  1,  6, -1,  7, -1,  8,  0,  2,  1,  5, -2,  6,  0,  2,  6,  7, -9,
  8,  0,  2,  5,  7, -7,  8,  0,  2,  4,  7, -5,  8,  0,  2,  3,  7, -3,  8,
  1,  2,  2,  7, -1,  8,  0,  2,  1,  7,  1,  8,  2,  1,  3,  8,  0,  2,  3,
  6, -7,  7,  1,  3,  2,  5, -3,  6, -4,  7,  0,  3,  2,  6, -3,  7, -2,  8,
  0,  2,  2,  6, -4,  7,  1,  3,  2,  6, -5,  7,  2,  8,  1,  3,  5,  5, -9,
  6, -8,  7,  0,  3,  2,  5, -4,  6, -1,  7,  0,  3,  1,  6,  3,  7, -8,  8,
  0,  3,  2,  6, -8,  7,  1,  8,  0,  3,  2,  5, -7,  6,  4,  7,  0,  3,  4,
  5,-10,  6,  2,  7,  0,  2,  1,  6, -2,  8,  0,  2,  1,  6, -1,  7,  2,  2,
  8,  7,-12,  8,  0,  2,  7,  7,-10,  8,  0,  2,  6,  7, -8,  8,  1,  2,  5,
  7, -6,  8,  0,  2,  4,  7, -4,  8,  2,  1,  2,  7,  4,  1,  4,  8,  0,  2,
  1,  7, -6,  8,  0,  2,  2,  7, -8,  8,  1,  2,  3,  7,-10,  8,  0,  2,  4,
  7,-12,  8,  0,  3,  1,  6, -6,  7,  2,  8,  0,  2,  1,  6, -5,  7,  1,  3,
  1,  6, -4,  7, -2,  8,  0,  3,  1,  5, -4,  6,  2,  7,  1,  3,  1,  5, -2,
  6,  1,  7,  0,  2,  7,  7, -9,  8,  0,  2,  6,  7, -7,  8,  0,  2,  5,  7,
 -5,  8,  0,  2,  4,  7, -3,  8,  0,  2,  3,  7, -1,  8,  0,  2,  2,  7,  1,
  8,  0,  2,  3,  6, -6,  7,  1,  3,  3,  6, -7,  7,  2,  8,  0,  3,  2,  5,
 -3,  6, -3,  7,  1,  3,  2,  6, -2,  7, -2,  8,  0,  2,  2,  6, -3,  7,  1,
  3,  2,  6, -4,  7,  2,  8,  0,  3,  2,  5, -7,  6,  3,  7,  1,  3,  1,  6,
  1,  7, -2,  8,  0,  1,  1,  6,  1,  2,  8,  7,-10,  8,  0,  2,  7,  7, -8,
  8,  0,  2,  6,  7, -6,  8,  0,  2,  5,  7, -4,  8,  0,  2,  4,  7, -2,  8,
  0,  1,  3,  7,  3,  2,  2,  7,  2,  8,  0,  2,  1,  7,  4,  8,  0,  2,  1,
  5, -4,  7,  0,  2,  1,  6, -6,  7,  0,  2,  8,  7, -9,  8,  0,  2,  7,  7,
 -7,  8,  0,  2,  6,  7, -5,  8,  0,  2,  5,  7, -3,  8,  0,  2,  4,  7, -1,
  8,  0,  3,  3,  6, -4,  7, -2,  8,  0,  2,  3,  6, -5,  7,  1,  3,  3,  6,
 -6,  7,  2,  8,  0,  3,  2,  5, -3,  6, -2,  7,  1,  3,  2,  6, -1,  7, -2,
  8,  0,  2,  2,  6, -2,  7,  0,  3,  2,  6, -3,  7,  2,  8,  0,  3,  2,  5,
 -7,  6,  2,  7,  1,  2,  1,  6,  1,  7,  0,  2,  9,  7,-10,  8,  0,  2,  8,
  7, -8,  8,  0,  2,  7,  7, -6,  8,  0,  2,  6,  7, -4,  8,  0,  2,  5,  7,
 -2,  8,  0,  1,  4,  7,  1,  2,  3,  7,  2,  8,  0,  2,  1,  5, -3,  7,  0,
  2,  9,  7, -9,  8,  0,  2,  8,  7, -7,  8,  0,  3,  3,  6, -3,  7, -2,  8,
  0,  2,  3,  6, -4,  7,  1,  3,  3,  6, -5,  7,  2,  8,  0,  3,  2,  5, -3,
  6, -1,  7,  0,  3,  2,  5, -8,  6,  4,  7,  0,  2,  2,  6, -2,  8,  0,  2,
  2,  6, -1,  7,  1,  3,  2,  6, -2,  7,  2,  8,  0,  3,  2,  5, -7,  6,  1,
  7,  0,  2,  6,  7, -2,  8,  0,  1,  5,  7,  0,  3,  3,  6, -4,  7,  1,  8,
  0,  2,  1,  5, -2,  7,  2,  3,  1,  5, -3,  7,  2,  8,  0,  3,  1,  5, -1,
  6,  1,  7,  0,  2,  4,  6, -6,  7,  0,  2,  3,  6, -3,  7,  0,  1,  2,  6,
  0,  3,  2,  5, -4,  6,  3,  7,  0,  3,  1,  5,  1,  6, -4,  7,  0,  3,  3,
  5, -5,  6, -1,  7,  0,  1,  6,  7,  1,  3,  1,  5,  1,  7, -4,  8,  0,  2,
  1,  5, -2,  8,  0,  2,  1,  5, -1,  7,  1,  3,  1,  5, -2,  7,  2,  8,  0,
  3,  1,  5, -3,  7,  4,  8,  0,  3,  1,  5, -5,  6,  1,  7,  1,  3,  1,  5,
 -1,  6,  2,  7,  0,  2,  4,  6, -5,  7,  0,  2,  3,  6, -2,  7,  0,  3,  1,
  5,  1,  7, -2,  8,  0,  1,  1,  5,  1,  2,  4,  6, -4,  7,  0,  2,  3,  6,
 -1,  7,  0,  3,  3,  5, -5,  6,  1,  7,  0,  2,  5,  6, -6,  7,  0,  2,  4,
  6, -3,  7,  0,  2,  5,  6, -5,  7,  0,  2,  6,  6, -6,  7,  0,  2,  2,  5,
 -3,  7,  0,  2,  2,  5, -2,  7,  0,  2,  2,  5, -2,  8,  0,  2,  2,  5, -1,
  7,  1,  3,  2,  5, -2,  7,  2,  8,  0,  1,  2,  5,  0,  2,  3,  5, -3,  7,
  0,  2,  3,  5, -1,  7,  0, -1);

nepargs: array[0..368] of shortint =
( 0,  3,  2,  1,  7, -2,  8,  0,  3,  3,  5, -8,  6,  3,  8,  0,  2,  2,  7,
 -4,  8,  0,  3,  1,  5, -3,  6,  3,  8,  0,  2,  3,  7, -6,  8,  0,  2,  4,
  7, -8,  8,  0,  3,  1,  6, -6,  7,  6,  8,  0,  3,  1,  6, -5,  7,  4,  8,
  0,  3,  1,  6, -4,  7,  2,  8,  0,  2,  1,  6, -3,  7,  0,  3,  1,  6, -2,
  7, -1,  8,  0,  2,  5,  7, -9,  8,  1,  2,  4,  7, -7,  8,  1,  2,  3,  7,
 -5,  8,  1,  2,  2,  7, -3,  8,  0,  2,  1,  7, -1,  8,  1,  1,  1,  8,  2,
  2,  1,  7, -3,  8,  0,  2,  2,  7, -5,  8,  1,  3,  1,  6, -6,  7,  5,  8,
  0,  3,  1,  6, -5,  7,  3,  8,  0,  2,  5,  7, -8,  8,  0,  2,  4,  7, -6,
  8,  0,  2,  3,  7, -4,  8,  0,  2,  2,  7, -2,  8,  1,  1,  1,  7,  0,  1,
  2,  8,  2,  2,  1,  7, -4,  8,  0,  2,  5,  7, -7,  8,  0,  2,  4,  7, -5,
  8,  0,  2,  3,  7, -3,  8,  0,  2,  2,  7, -1,  8,  0,  2,  1,  7,  1,  8,
  0,  1,  3,  8,  1,  2,  1,  6, -2,  8,  1,  2,  5,  7, -6,  8,  0,  2,  4,
  7, -4,  8,  0,  1,  4,  8,  1,  3,  2,  5, -4,  6, -1,  8,  1,  3,  1,  6,
  1,  7, -3,  8,  0,  2,  1,  6, -1,  8,  1,  3,  1,  6, -1,  7,  1,  8,  0,
  3,  2,  5, -6,  6,  1,  8,  0,  2,  5,  7, -5,  8,  1,  1,  1,  6,  0,  2,
  6,  7, -6,  8,  0,  2,  7,  7, -7,  8,  0,  2,  2,  6, -2,  8,  0,  3,  2,
  5, -3,  6, -1,  8,  0,  2,  2,  6, -1,  8,  1,  2,  1,  5, -2,  8,  0,  3,
  3,  5, -5,  6, -1,  8,  0,  2,  4,  7,  5,  8,  0,  2,  1,  5, -1,  8,  1,
  3,  1,  5, -1,  7,  1,  8,  1,  3,  1,  5, -5,  6,  1,  8,  1,  1,  1,  5,
  0,  2,  2,  5, -1,  8,  1, -1);

pluargs: array[0..1086] of shortint =
( 0,  7,  2,  3,  7, -9,  9,  0,  2,  4,  7,-12,  9,  0,  2,  4,  7, -8,  8,
  0,  3, -4,  7,  5,  8,  4,  9,  0,  3,  3,  7, -5,  8, -1,  9,  0,  2,  1,
  6, -8,  9,  1,  2,  3,  8, -5,  9,  1,  2,  1,  6, -9,  9,  2,  3,  6,  7,
 -6,  8, -8,  9,  0,  3,  4,  7,-10,  8,  4,  9,  2,  2,  3,  7, -8,  9,  0,
  1,  1,  9,  7,  2,  3,  7,-10,  9,  0,  3,  4,  7,-10,  8,  2,  9,  2,  3,
  5,  7,-12,  8,  2,  9,  0,  2,  1,  6, -7,  9,  0,  1,  1,  8,  3,  2,  1,
  6,-10,  9,  0,  3,  6,  7,-12,  8,  2,  9,  0,  3,  5,  7,-10,  8,  2,  9,
  0,  2,  5,  7,-13,  9,  0,  2,  4,  7,-10,  9,  0,  2,  3,  7, -7,  9,  0,
  1,  2,  9,  7,  2,  3,  7,-11,  9,  0,  3,  4,  7, -9,  8,  4,  9,  2,  3,
  3,  7, -5,  8,  1,  9,  2,  2,  1,  6, -6,  9,  0,  2,  7,  8,-13,  9,  0,
  2,  3,  8, -2,  9,  1,  3,  1,  7, -5,  8,  2,  9,  1,  3,  6,  7,-12,  8,
  3,  9,  1,  2,  5,  7,-12,  9,  1,  2,  4,  7, -9,  9,  1,  2,  2,  7, -3,
  9,  1,  1,  1,  7,  0,  1,  3,  9,  5,  2,  3,  7,-12,  9,  1,  3,  5,  7,
 -9,  8,  2,  9,  0,  3,  4,  7, -7,  8,  2,  9,  1,  3,  3,  7, -5,  8,  2,
  9,  0,  3,  2,  7, -5,  8,  5,  9,  0,  2,  1,  6, -5,  9,  0,  2,  3,  8,
 -1,  9,  2,  2,  1,  6,-12,  9,  0,  3,  2,  7, -7,  8,  1,  9,  0,  2,  5,
  7,-11,  9,  0,  2,  4,  7, -8,  9,  0,  2,  2,  7, -2,  9,  0,  1,  4,  9,
  7,  3,  2,  7, -8,  8,  2,  9,  0,  3,  5,  7, -9,  8,  3,  9,  0,  3,  4,
  7, -9,  8,  6,  9,  0,  3,  3,  7, -5,  8,  3,  9,  1,  2,  2,  7, -1,  8,
  1,  2,  3,  8, -9,  9,  0,  2,  9,  8, -9,  9,  0,  2,  1,  6,-13,  9,  0,
  3,  2,  7, -5,  8, -3,  9,  0,  2,  6,  7,-13,  9,  1,  2,  5,  7,-10,  9,
  0,  2,  4,  7, -7,  9,  0,  2,  3,  7, -4,  9,  0,  1,  5,  9,  7,  3,  6,
  7, -9,  8,  1,  9,  1,  3,  4,  7, -5,  8,  1,  9,  1,  3,  3,  7, -3,  8,
  1,  9,  0,  2,  1,  6, -3,  9,  2,  2,  3,  8,-10,  9,  0,  2,  1,  8,  4,
  9,  0,  2,  5,  8, -2,  9,  0,  2, 11,  8,-11,  9,  0,  3,  1,  7, -9,  8,
  5,  9,  0,  2,  6,  7,-12,  9,  0,  2,  5,  7, -9,  9,  0,  2,  4,  7, -6,
  9,  0,  2,  3,  7, -3,  9,  0,  1,  6,  9,  6,  2,  2,  7,-12,  9,  0,  3,
  6,  7, -9,  8,  2,  9,  0,  3,  3,  7,-12,  8,  3,  9,  0,  3,  4,  7,-10,
  8, -3,  9,  1,  3,  3,  7, -3,  8,  2,  9,  0,  2,  1,  6, -2,  9,  2,  2,
  1,  8,  5,  9,  0,  2, 13,  8,-13,  9,  1,  3,  2,  7, -9,  8,  1,  9,  0,
  2,  6,  7,-11,  9,  0,  2,  5,  7, -8,  9,  0,  2,  4,  7, -5,  9,  0,  2,
  3,  7, -2,  9,  0,  1,  7,  9,  7,  3,  6,  7, -9,  8,  3,  9,  0,  2,  1,
  6, -1,  9,  4,  2,  3,  8,  3,  9,  0,  2,  7,  7,-13,  9,  1,  2,  3,  7,
 -1,  9,  0,  2,  2,  7,  2,  9,  0,  1,  8,  9,  6,  3,  7,  7, -9,  8,  1,
  9,  0,  1,  1,  6,  0,  1,  3,  7,  0,  2,  2,  7,  3,  9,  0,  1,  9,  9,
  5,  3,  1,  7,-10,  8,  3,  9,  0,  3,  2,  7,-12,  8,  3,  9,  1,  2,  1,
  6,  1,  9,  0,  3,  1,  7, -1,  8,  8,  9,  0,  2,  3,  7,  1,  9,  1,  2,
  2,  7,  4,  9,  0,  2,  1,  7,  7,  9,  0,  2,  4,  8,  4,  9,  1,  2, 12,
  8, -8,  9,  0,  3,  1,  7,-10,  8,  2,  9,  1,  2,  1,  6,  2,  9,  0,  1,
 11,  9,  2,  2, 12,  8, -7,  9,  0,  3,  1,  7,-10,  8,  1,  9,  1,  1,  4,
  7,  0,  1, 12,  9,  0,  2,  6,  8,  3,  9,  0,  3,  1,  7, -2,  8,-12,  9,
  0,  3,  7,  7, -7,  8,  2,  9,  1,  2,  2,  6, -4,  9,  1,  1, 13,  9,  0,
  2, 10,  8, -2,  9,  1,  2,  4,  7,  2,  9,  0,  2,  2,  6, -3,  9,  0,  2,
  2,  7,  8,  9,  1,  2,  8,  8,  2,  9,  0,  1,  5,  7,  1,  2,  4,  7,  3,
  9,  0,  2,  3,  7,  6,  9,  0,  2,  1,  5, -6,  9,  0,  3,  2,  7,  8,  8,
 -3,  9,  0,  3,  1,  7,  6,  8,  3,  9,  0,  2,  6,  8,  6,  9,  0,  3,  8,
  7, -7,  8,  2,  9,  0,  2,  9,  7,-11,  9,  0,  2,  5,  7,  1,  9,  1,  2,
  4,  7,  4,  9,  0,  2,  2,  6, -1,  9,  0,  3,  2,  6, -1,  7,  2,  9,  0,
  2,  2,  7, 10,  9,  0,  2,  1,  7, 13,  9,  0,  2,  8,  7, -7,  9,  0,  2,
  7,  7, -4,  9,  0,  2,  6,  7, -1,  9,  0,  2,  5,  7,  3,  9,  0,  2,  4,
  7,  5,  9,  0,  1,  2,  6,  0,  2,  1,  5, -4,  9,  1,  3,  1,  6,  9,  8,
 -5,  9,  0,  2,  1,  5, -3,  9,  4,  2,  1,  5, -2,  9,  4,  3,  9,  7, -9,
  8,  6,  9,  0,  2,  8,  7, -4,  9,  0,  2,  7,  7, -1,  9,  0,  2,  1,  6,
  3,  9,  0,  2,  2,  6,  3,  9,  0,  2,  1,  5, -1,  9,  3,  3,  6,  7, -3,
  8,  7,  9,  1,  1,  1,  5,  0,  2,  2,  6,  5,  9,  0,  2,  1,  5,  1,  9,
  0,  2,  1,  5,  2,  9,  0,  2,  1,  5,  3,  9,  0,  2,  2,  5, -4,  9,  0,
  2,  2,  5, -3,  9,  0,  2,  2,  5, -2,  9,  1,  2,  2,  5, -1,  9,  1,  1,
  2,  5,  0, -1);

mlatargs: array[0..3156] of shortint =
( 0,  1,  3,  1, 10,  1, 12, -1, 11,  1,  4,  2, 10,  2, 12, -1, 13, -1, 11,
  0,  5,  2, 10, -1, 13, -1, 11,  3,  2, -3,  3,  0,  5,  2, 10, -1, 13, -1,
 11,  2,  3, -2,  5,  0,  2, -1, 13,  1, 14,  1,  5, -1, 13,  1, 11,  4,  3,
 -8,  4,  3,  5,  0,  2,  1, 13, -1, 11,  0,  5,  1, 13, -1, 11,  4,  3, -8,
  4,  3,  5,  0,  5,  2, 10, -1, 13, -1, 11,  2,  3, -3,  5,  0,  4,  1, 10,
  1, 12, -2, 13,  1, 11,  0,  4,  1, 13, -1, 11,  1,  2, -1,  3,  0,  5,  2,
 10, -1, 13, -1, 11,  2,  2, -2,  3,  0,  3,  1, 10, -2, 13,  1, 11,  0,  4,
  1, 13, -1, 11,  1,  3, -1,  5,  0,  4, -1, 13,  1, 11,  1,  2, -1,  3,  0,
  3,  1, 12,  1, 13, -1, 11,  1,  4,  2, 10,  1, 12, -1, 13, -1, 11,  1,  2,
  1, 10, -1, 11,  0,  4, -1, 13,  1, 11,  1,  3, -1,  5,  0,  3,  1, 12, -1,
 13,  1, 11,  1,  3,  2, 10, -3, 13,  1, 11,  0,  3,  2, 12,  1, 13, -1, 11,
  0,  3, -2, 10,  1, 13,  1, 14,  0,  6, -2, 10,  1, 13,  1, 11,  4,  3, -8,
  4,  3,  5,  0,  3,  2, 10, -1, 13, -1, 11,  0,  6,  2, 10, -1, 13, -1, 11,
  4,  3, -8,  4,  3,  5,  0,  4, -1, 13,  1, 11,  2,  3, -2,  5,  0,  4, -1,
 13,  1, 11,  3,  2, -3,  3,  0,  3,  1, 10, -1, 12, -1, 11,  0,  3,  2, 12,
 -1, 13,  1, 11,  0,  3,  2, 10,  1, 13, -3, 11,  0,  5, -2, 10,  1, 13,  1,
 11,  1,  2, -1,  3,  0,  4,  2, 10, -1, 12, -3, 13,  1, 11,  0,  3,  3, 10,
 -2, 13, -1, 11,  0,  5, -2, 10,  1, 13,  1, 11,  1,  3, -1,  5,  0,  4,  2,
 10, -1, 12, -1, 13, -1, 11,  1,  2,  3, 10, -3, 11,  0,  5, -2, 10,  1, 13,
  1, 11,  2,  2, -2,  3,  0,  4,  2, 10, -1, 12,  1, 13, -3, 11,  0,  3,  4,
 10, -3, 13, -1, 11,  0,  4,  2, 10, -2, 12, -1, 13, -1, 11,  1,  3,  4, 10,
 -1, 13, -3, 11,  0,  4,  2, 10, -3, 12, -1, 13, -1, 11,  0,  3,  4, 10, -1,
 12, -3, 11,  0,  3,  2, 10, -3, 12, -1, 11,  0,  4,  4, 10, -1, 12, -2, 13,
 -1, 11,  0,  2,  4, 10, -3, 11,  0,  3,  2, 10, -2, 12, -1, 11,  1,  4,  3,
 10, -1, 12, -1, 13, -1, 11,  0,  4, -2, 10,  1, 11,  2,  3, -2,  5,  0,  3,
  4, 10, -2, 13, -1, 11,  0,  4, -2, 10,  1, 11,  2,  2, -2,  3,  0,  3,  2,
 10, -1, 12, -1, 11,  2,  3, -2, 10,  1, 12,  1, 14,  0,  4, -2, 10,  1, 11,
  2,  3, -2,  4,  0,  4, -2, 10,  1, 11,  1,  3, -1,  5,  0,  3,  3, 10, -1,
 13, -1, 11,  0,  4, -2, 10,  1, 11,  3,  2, -4,  3,  0,  4, -2, 10,  1, 11,
  1,  3, -2,  5,  0,  4,  2, 10, -1, 12, -2, 13,  1, 11,  0,  4, -2, 10,  1,
 11,  1,  2, -1,  3,  0,  2, -1, 10,  1,  2,  0,  3,  2, 10,  2, 13, -3, 11,
  0,  4, -2, 10,  1, 11,  2,  2, -3,  3,  0,  3,  2, 12, -2, 13,  1, 11,  0,
  4,  1, 10, -1, 12,  1, 13, -1, 11,  0,  3, -2, 10,  1, 11,  1,  5,  0,  4,
  2, 10, -1, 11,  1,  3, -2,  4,  0,  3,  2, 10, -2, 11,  1, 14,  0,  4, -2,
 10,  1, 11,  8,  2,-13,  3,  0,  5, -2, 10, -1, 13,  1, 11, 18,  2,-16,  3,
  0,  5,  2, 10, -1, 11,  4,  3, -8,  4,  3,  5,  1,  2,  2, 10, -1, 11,  1,
  5, -2, 10,  1, 11,  4,  3, -8,  4,  3,  5,  1,  5,  2, 10, -1, 13, -1, 11,
 18,  2,-16,  3,  0,  4,  2, 10, -1, 11,  8,  2,-13,  3,  0,  2, -2, 10,  1,
 14,  1,  4, -2, 10,  1, 11,  1,  3, -2,  4,  0,  3,  2, 10, -1, 11,  1,  5,
  0,  2,  2, 12, -1, 11,  0,  4,  3, 10,  1, 12, -1, 13, -1, 11,  0,  4,  2,
 10, -1, 11,  2,  2, -3,  3,  0,  3,  2, 10, -2, 13,  1, 11,  0,  4,  2, 10,
 -1, 11,  1,  2, -1,  3,  0,  3,  1, 10,  1,  2, -2,  3,  0,  3,  1, 12, -2,
 13,  1, 11,  1,  3,  1, 10,  1, 13, -1, 11,  0,  4,  2, 10, -1, 11,  1,  3,
 -1,  5,  0,  3,  2, 10,  1, 12, -1, 11,  2,  3, -2, 10, -1, 12,  1, 14,  0,
  2,  1, 12, -1, 11,  1,  3,  1, 10, -1, 13,  1, 11,  0,  4,  2, 10, -1, 11,
  2,  2, -2,  3,  0,  3,  1, 10,  2,  2, -3,  3,  0,  4,  2, 10,  1, 12, -2,
 13,  1, 11,  0,  3, -1, 10,  1,  2, -2,  3,  0,  3, -1, 11,  1,  2, -1,  3,
  0,  2,  2, 13, -1, 11,  0,  2, -2, 13,  1, 14,  0,  4,  2, 10, -1, 11,  2,
  3, -2,  5,  0,  4,  2, 10, -1, 11,  3,  2, -3,  3,  0,  4,  2, 10,  2, 12,
 -2, 13, -1, 11,  0,  3,  1, 10,  1,  3, -2,  5,  0,  4,  1, 10,  1, 12,  1,
 13, -1, 11,  0,  3,  1, 10,  3,  2, -4,  3,  0,  3,  1, 10,  1,  3, -1,  5,
  0,  3,  1, 10,  1,  3, -2,  6,  0,  3,  1, 10,  2,  3, -2,  4,  0,  4,  1,
 10,  1, 12, -1, 13, -1, 11,  0,  3,  2, 10,  2, 12, -1, 11,  2,  4,  1, 10,
  1,  3,  2,  5, -5,  6,  1,  1,  1, 14,  2,  3,  1, 10,  8,  2,-12,  3,  1,
  5, -2, 10,  1, 13, -1, 11, 20,  2,-21,  3,  0,  5,  2, 10, -2, 13,  1, 11,
  2,  3, -3,  5,  0,  3,  1, 10,  1,  3,  1,  6,  0,  4, -1, 13, -1, 11, 26,
  2,-29,  3,  0,  3, -1, 11,  8,  2,-13,  3,  0,  4, -1, 13, -1, 11, 18,  2,
-16,  3,  2,  4, -1, 13,  1, 11, 10,  2, -3,  3,  1,  1,  1, 11,  3,  4, -1,
 13, -1, 11, 10,  2, -3,  3,  1,  4, -1, 13,  1, 11, 18,  2,-16,  3,  2,  3,
  1, 11,  8,  2,-13,  3,  0,  2,  1, 10,  2,  4,  0,  4,  2, 10, -1, 11,  5,
  2, -6,  3,  1,  5,  2, 10, -2, 13, -1, 11,  2,  3, -3,  5,  0,  5, -2, 10,
  1, 13,  1, 11, 20,  2,-21,  3,  0,  3,  1, 10,  1,  3,  1,  5,  0,  2, -2,
 11,  1, 14,  0,  5,  2, 10, -2, 13,  1, 11,  2,  3, -2,  5,  0,  3,  1, 10,
  5,  2, -7,  3,  0,  4,  1, 10,  1, 12, -1, 13,  1, 11,  0,  3,  1, 10,  2,
  2, -2,  3,  0,  4,  2, 10,  2, 12, -2, 13,  1, 11,  0,  2,  2, 13, -3, 11,
  0,  4,  2, 10, -1, 11,  4,  2, -4,  3,  0,  3,  1, 10,  4,  2, -5,  3,  0,
  3,  1, 10, -3, 13,  1, 11,  0,  2,  1, 10,  1,  2,  0,  3,  1, 11,  1,  2,
 -1,  3,  0,  4,  2, 10, -1, 11,  3,  3, -3,  5,  0,  3,  1, 12,  2, 13, -1,
 11,  1,  4,  2, 10,  1, 12, -2, 13, -1, 11,  0,  3,  1, 10, -1, 13, -1, 11,
  0,  3,  1, 11,  1,  3, -1,  5,  0,  2,  1, 12,  1, 11,  2,  4,  2, 10, -1,
 11,  5,  2, -5,  3,  0,  3,  1, 10,  5,  2, -6,  3,  0,  3,  2, 10,  1, 12,
 -3, 11,  0,  3,  1, 10,  2,  2, -1,  3,  0,  3,  2, 10, -4, 13,  1, 11,  0,
  3, -2, 10,  2, 13,  1, 14,  0,  3,  2, 10, -2, 13, -1, 11,  0,  3,  1, 10,
  3,  2, -2,  3,  0,  4,  1, 10, -1, 12, -1, 13, -1, 11,  0,  2,  2, 12,  1,
 11,  0,  2,  2, 10, -3, 11,  0,  3,  1, 10,  4,  2, -3,  3,  0,  4,  2, 10,
 -1, 12, -2, 13, -1, 11,  1,  3,  2, 10, -1, 12, -3, 11,  0,  3,  4, 10, -4,
 13, -1, 11,  0,  4,  2, 10, -2, 12, -2, 13, -1, 11,  0,  4,  4, 10, -2, 12,
 -1, 13, -1, 11,  0,  3,  6, 10, -3, 13, -1, 11,  0,  4,  4, 10, -1, 12, -1,
 13, -1, 11,  1,  4,  2, 10, -3, 12, -1, 13,  1, 11,  0,  3,  5, 10, -2, 13,
 -1, 11,  0,  3,  4, 10,  1, 13, -3, 11,  0,  4,  2, 10, -2, 12,  1, 13, -1,
 11,  0,  3,  3, 10, -1, 12, -1, 11,  0,  3,  4, 10, -1, 13, -1, 11,  0,  4,
  2, 10, -2, 12, -1, 13,  1, 11,  1,  3,  4, 10, -3, 13,  1, 11,  0,  4,  2,
 10, -1, 12,  1, 13, -1, 11,  1,  5, -2, 10,  1, 13, -1, 11,  2,  2, -2,  3,
  0,  2,  3, 10, -1, 11,  0,  4,  4, 10,  1, 12, -1, 13, -1, 11,  0,  4,  2,
 10, -1, 12, -1, 13,  1, 11,  2,  5, -2, 10,  1, 13, -1, 11,  1,  3, -1,  5,
  0,  3,  3, 10, -2, 13,  1, 11,  0,  5, -2, 10,  1, 13, -1, 11,  1,  2, -1,
  3,  0,  3,  2, 10,  1, 13, -1, 11,  0,  3, -2, 10, -1, 13,  1, 14,  0,  3,
  2, 12, -1, 13, -1, 11,  1,  3,  3, 10,  1, 12, -1, 11,  0,  3,  1, 10, -1,
 12,  1, 11,  0,  4, -1, 13, -1, 11,  3,  2, -3,  3,  0,  4, -1, 13, -1, 11,
  2,  3, -2,  5,  0,  3,  2, 10, -1, 13,  1, 14,  0,  4, -2, 10, -1, 11, 18,
  2,-16,  3,  0,  6,  2, 10, -1, 13,  1, 11,  4,  3, -8,  4,  3,  5,  0,  3,
  2, 10, -1, 13,  1, 11,  0,  6, -2, 10,  1, 13, -1, 11,  4,  3, -8,  4,  3,
  5,  0,  5,  2, 10, -2, 13,  1, 11, 18,  2,-16,  3,  0,  4, -2, 10,  1, 13,
 -2, 11,  1, 14,  0,  3,  1, 12, -3, 13,  1, 11,  0,  3,  1, 10,  2, 13, -1,
 11,  0,  4,  2, 10,  1, 12,  1, 13, -1, 11,  1,  3,  1, 12, -1, 13, -1, 11,
  1,  4, -1, 13, -1, 11,  1,  3, -1,  5,  0,  2,  1, 10,  1, 11,  0,  4,  2,
 10,  1, 12, -1, 13,  1, 11,  1,  3,  1, 12,  1, 13, -3, 11,  0,  4, -1, 13,
 -1, 11,  1,  2, -1,  3,  0,  5,  2, 10, -1, 13,  1, 11,  2,  2, -2,  3,  0,
  2,  3, 13, -1, 11,  0,  4,  1, 10,  1, 12, -2, 13, -1, 11,  0,  4,  2, 10,
  2, 12,  1, 13, -1, 11,  0,  2,  1, 13,  1, 14,  1,  5,  2, 10, -1, 13,  1,
 11,  2,  3, -3,  5,  0,  4, -2, 13, -1, 11, 18,  2,-16,  3,  1,  5,  1, 13,
  1, 11,  4,  3, -8,  4,  3,  5,  0,  2,  1, 13,  1, 11,  0,  5, -1, 13, -1,
 11,  4,  3, -8,  4,  3,  5,  0,  3,  1, 11, 18,  2,-16,  3,  1,  3, -1, 13,
 -2, 11,  1, 14,  0,  5,  2, 10, -1, 13,  1, 11,  2,  3, -2,  5,  0,  5,  2,
 10, -1, 13,  1, 11,  3,  2, -3,  3,  0,  3,  1, 10,  1, 12,  1, 11,  1,  4,
  2, 10,  2, 12, -1, 13,  1, 11,  1,  2,  1, 13, -3, 11,  0,  4,  1, 13,  1,
 11,  1,  2, -1,  3,  0,  3,  1, 12,  3, 13, -1, 11,  0,  4,  2, 10,  1, 12,
 -3, 13, -1, 11,  0,  3,  1, 10, -2, 13, -1, 11,  0,  4,  1, 13,  1, 11,  1,
  3, -1,  5,  0,  3,  1, 12,  1, 13,  1, 11,  1,  2,  1, 10, -3, 11,  0,  3,
  1, 12, -1, 13,  3, 11,  0,  3,  2, 10, -3, 13, -1, 11,  0,  3,  2, 12,  1,
 13,  1, 11,  0,  3,  2, 10, -1, 13, -3, 11,  0,  4,  2, 10, -1, 12, -3, 13,
 -1, 11,  0,  4,  2, 10, -1, 12, -1, 13, -3, 11,  0,  4,  6, 10, -1, 12, -2,
 13, -1, 11,  0,  3,  4, 10, -2, 12, -1, 11,  0,  3,  6, 10, -2, 13, -1, 11,
  0,  4,  4, 10, -2, 12, -2, 13,  1, 11,  0,  3,  4, 10, -1, 12, -1, 11,  1,
  3,  2, 10, -3, 12,  1, 11,  0,  3,  5, 10, -1, 13, -1, 11,  0,  4,  4, 10,
 -1, 12, -2, 13,  1, 11,  0,  4,  2, 10, -2, 12,  2, 13, -1, 11,  0,  2,  4,
 10, -1, 11,  0,  3,  2, 10, -2, 12,  1, 11,  1,  4,  3, 10, -1, 12, -1, 13,
  1, 11,  0,  3,  4, 10, -2, 13,  1, 11,  0,  4,  2, 10, -1, 12,  2, 13, -1,
 11,  0,  4, -2, 10, -1, 11,  2,  2, -2,  3,  0,  3,  3, 10,  1, 13, -1, 11,
  0,  3,  4, 10,  1, 12, -1, 11,  0,  3,  2, 10, -1, 12,  1, 11,  2,  4, -2,
 10, -1, 11,  1,  3, -1,  5,  0,  3,  3, 10, -1, 13,  1, 11,  0,  4,  4, 10,
  1, 12, -2, 13,  1, 11,  0,  3,  2, 10,  2, 13, -1, 11,  0,  3,  2, 12, -2,
 13, -1, 11,  0,  4,  1, 10, -1, 12,  1, 13,  1, 11,  0,  2,  2, 10,  1, 14,
  0,  5, -2, 10, -1, 13, -1, 11, 18,  2,-16,  3,  0,  2,  2, 10,  1, 11,  1,
  5,  2, 10, -1, 13,  1, 11, 18,  2,-16,  3,  0,  3, -2, 10, -2, 11,  1, 14,
  0,  4,  3, 10,  1, 12, -1, 13,  1, 11,  0,  3,  2, 10, -2, 13,  3, 11,  0,
  4,  2, 10,  1, 12,  2, 13, -1, 11,  0,  3,  1, 12, -2, 13, -1, 11,  1,  3,
  1, 10,  1, 13,  1, 11,  0,  3,  2, 10,  1, 12,  1, 11,  1,  2,  4, 13, -1,
 11,  0,  2,  2, 13,  1, 14,  0,  4, -3, 13, -1, 11, 18,  2,-16,  3,  0,  2,
  2, 13,  1, 11,  0,  4,  1, 13,  1, 11, 18,  2,-16,  3,  0,  4,  2, 10,  1,
 11,  2,  3, -2,  5,  0,  4,  1, 10,  1, 12,  1, 13,  1, 11,  0,  3,  2, 10,
  2, 12,  1, 11,  0,  2,  2, 11,  1, 14,  0,  1,  3, 11,  0,  3,  1, 10, -3,
 13, -1, 11,  0,  3,  1, 12,  2, 13,  1, 11,  1,  2,  1, 12,  3, 11,  0,  3,
  2, 10, -4, 13, -1, 11,  0,  3,  2, 12,  2, 13,  1, 11,  0,  3,  2, 10, -2,
 13, -3, 11,  0,  4,  6, 10, -1, 12, -1, 13, -1, 11,  0,  3,  6, 10, -1, 13,
 -1, 11,  0,  4,  4, 10, -2, 12, -1, 13,  1, 11,  0,  3,  6, 10, -3, 13,  1,
 11,  0,  4,  4, 10, -1, 12,  1, 13, -1, 11,  0,  4,  4, 10, -1, 12, -1, 13,
  1, 11,  1,  3,  5, 10, -2, 13,  1, 11,  0,  3,  4, 10,  1, 13, -1, 11,  0,
  4,  2, 10, -2, 12,  1, 13,  1, 11,  0,  3,  4, 10, -1, 13,  1, 11,  0,  4,
  2, 10, -1, 12,  3, 13, -1, 11,  0,  4,  4, 10,  1, 12,  1, 13, -1, 11,  0,
  4,  2, 10, -1, 12,  1, 13,  1, 11,  1,  2,  3, 10,  1, 11,  0,  4,  4, 10,
  1, 12, -1, 13,  1, 11,  0,  4,  2, 10, -1, 12, -1, 13,  3, 11,  0,  3,  2,
 10,  3, 13, -1, 11,  0,  3,  2, 10,  1, 13,  1, 14,  0,  3,  2, 10,  1, 13,
  1, 11,  0,  3,  3, 10,  1, 12,  1, 11,  0,  3,  2, 10, -1, 13,  3, 11,  0,
  4,  2, 10,  1, 12,  3, 13, -1, 11,  0,  3,  1, 12, -3, 13, -1, 11,  0,  3,
  1, 10,  2, 13,  1, 11,  0,  4,  2, 10,  1, 12,  1, 13,  1, 11,  1,  3,  1,
 12, -1, 13, -3, 11,  0,  2,  1, 10,  3, 11,  0,  2,  5, 13, -1, 11,  0,  2,
  3, 13,  1, 11,  0,  4,  1, 10,  1, 12,  2, 13,  1, 11,  0,  2,  1, 13,  3,
 11,  0,  3,  1, 12,  3, 13,  1, 11,  0,  3,  1, 12,  1, 13,  3, 11,  0,  3,
  2, 10, -5, 13, -1, 11,  0,  3,  6, 10, -1, 12, -1, 11,  0,  4,  6, 10, -1,
 12, -2, 13,  1, 11,  0,  2,  6, 10, -1, 11,  0,  3,  4, 10, -2, 12,  1, 11,
  0,  3,  6, 10, -2, 13,  1, 11,  0,  4,  4, 10, -1, 12,  2, 13, -1, 11,  0,
  3,  4, 10, -1, 12,  1, 11,  0,  3,  4, 10,  2, 13, -1, 11,  0,  4,  2, 10,
 -2, 12,  2, 13,  1, 11,  0,  2,  4, 10,  1, 11,  0,  3,  4, 10, -2, 13,  3,
 11,  0,  4,  2, 10, -1, 12,  2, 13,  1, 11,  0,  3,  3, 10,  1, 13,  1, 11,
  0,  3,  4, 10,  1, 12,  1, 11,  0,  3,  2, 10, -1, 12,  3, 11,  0,  3,  2,
 10,  4, 13, -1, 11,  0,  3,  2, 10,  2, 13,  1, 11,  0,  2,  2, 10,  3, 11,
  0,  3,  1, 12, -4, 13, -1, 11,  0,  3,  1, 10,  3, 13,  1, 11,  0,  4,  2,
 10,  1, 12,  2, 13,  1, 11,  0,  2,  4, 13,  1, 11,  0,  2,  2, 13,  3, 11,
  0,  1,  5, 11,  0,  3,  1, 12,  4, 13,  1, 11,  0,  4,  6, 10, -1, 12, -1,
 13,  1, 11,  0,  3,  6, 10,  1, 13, -1, 11,  0,  3,  6, 10, -1, 13,  1, 11,
  0,  4,  4, 10, -1, 12,  1, 13,  1, 11,  0,  3,  4, 10,  1, 13,  1, 11,  0,
  3,  4, 10, -1, 13,  3, 11,  0,  4,  2, 10, -1, 12,  3, 13,  1, 11,  0,  4,
  4, 10,  1, 12,  1, 13,  1, 11,  0,  3,  2, 10,  3, 13,  1, 11,  0,  3,  2,
 10,  1, 13,  3, 11,  0,  2,  5, 13,  1, 11,  0,  2,  3, 13,  3, 11,  0,  2,
  6, 10,  1, 11,  0,  3,  4, 10,  2, 13,  1, 11,  0,  3,  2, 10,  4, 13,  1,
 11,  0, -1);

mlrargs: array[0..5018] of shortint =
( 0,  3,  3,  4,  3, -8,  4,  3,  5,  1,  2,  2,  5, -5,  6,  2,  5, -1, 10,
  2, 13, -1, 11,  3,  3, -7,  4,  0,  3,  1, 13, -1, 11,  2,  5,  1,  2,  4,
  5,-10,  6,  0,  4,  2, 10, -2, 13, 14,  3,-23,  4,  1,  3,  3,  2, -7,  3,
  4,  4,  1,  3, -1, 13, 18,  2,-16,  3,  2,  2,  8,  2,-13,  3,  1,  5,  2,
 10, -2, 13,  2,  3, -3,  5,  1,  6,  0,  3, -1, 13, 26,  2,-29,  3,  0,  3,
  1, 10, -1, 11,  2,  4,  1,  4,  1, 10, -1, 13,  3,  2, -4,  3,  1,  4,  1,
 10, -1, 13,  3,  3, -4,  4,  0,  3, -1, 10, 15,  2,-12,  3,  0,  4,  2, 10,
 -3, 13, 24,  2,-24,  3,  0,  3, -1, 10, 23,  2,-25,  3,  0,  4,  1, 10, -1,
 11,  1,  3,  1,  6,  0,  4,  2, 10, -2, 11,  5,  2, -6,  3,  0,  4,  2, 10,
 -2, 13,  6,  2, -8,  3,  0,  4, -2, 10,  1, 13, 12,  2, -8,  3,  1,  5, -1,
 10,  1, 13, -1, 11, 20,  2,-20,  3,  1,  4, -2, 10,  1, 13,  3,  1, -1,  3,
  1,  5,  2, 10, -2, 13,  2,  3, -5,  5,  5,  6,  0,  4,  2, 10, -2, 13,  2,
  3, -3,  5,  1,  4,  2, 10, -2, 13,  6,  3, -8,  4,  0,  4, -2, 10,  1, 13,
 20,  2,-21,  3,  1,  4,  1, 10, -1, 11,  1,  3,  1,  5,  0,  1,  1,  6,  0,
  4,  2, 10, -2, 13,  5,  3, -6,  4,  0,  3,  3,  2, -5,  3,  2,  5,  0,  2,
 -1, 11,  1, 14,  1,  4,  2, 10, -2, 13,  2,  3, -2,  5,  0,  2,  1,  3, -2,
  4,  1,  4,  1, 10, -1, 11,  5,  2, -7,  3,  0,  1,  1,  5,  0,  2,  7,  3,
-13,  4,  0,  4, -2, 10,  1, 13, 15,  2,-13,  3,  0,  4,  2, 10, -2, 13,  3,
  2, -3,  3,  0,  2, -2, 11,  2, 14,  1,  3,  1, 10,  1, 12, -1, 13,  1,  3,
 -1, 13, 21,  2,-21,  3,  0,  2,  3,  2, -5,  3,  0,  2,  2,  3, -4,  4,  1,
  2,  5,  2, -8,  3,  0,  3, -1, 13, 23,  2,-24,  3,  0,  2,  6,  3,-11,  4,
  0,  1,  2,  5,  0,  2,  3,  3, -6,  4,  0,  2,  5,  3, -9,  4,  0,  4,  1,
 10, -1, 11,  1,  3, -2,  5,  0,  3,  2, 10,  2, 12, -2, 13,  1,  2,  2,  2,
 -3,  3,  2,  2,  4,  3, -7,  4,  0,  2,  2, 13, -2, 11,  0,  2,  3,  3, -5,
  4,  0,  2,  1,  2, -2,  3,  0,  2,  2,  3, -3,  4,  0,  4,  1, 10, -1, 11,
  4,  2, -5,  3,  0,  2,  1,  3, -1,  4,  0,  2,  4,  2, -6,  3,  0,  4,  2,
 10, -2, 13,  2,  2, -2,  3,  0,  3,  1, 10, -1, 11,  1,  2,  0,  2,  1,  2,
 -1,  3,  0,  3,  1, 12,  2, 13, -2, 11,  0,  2,  5,  3, -8,  4,  0,  2,  1,
  3, -3,  5,  0,  3,  2, 10,  1, 12, -2, 13,  1,  2,  4,  3, -6,  4,  0,  2,
  1,  3, -2,  5,  1,  2,  3,  3, -4,  4,  0,  2,  3,  2, -4,  3,  1,  2,  1,
 10, -1, 13,  0,  2,  1,  3, -1,  5,  0,  2,  1,  3, -2,  6,  0,  2,  2,  3,
 -2,  4,  0,  2,  1,  3, -1,  6,  0,  2,  8,  2,-14,  3,  0,  3,  1,  3,  2,
  5, -5,  6,  1,  3,  5,  3, -8,  4,  3,  5,  1,  1,  1, 12,  3,  3,  3,  3,
 -8,  4,  3,  5,  1,  3,  1,  3, -2,  5,  5,  6,  0,  2,  8,  2,-12,  3,  0,
  2,  1,  3,  1,  5,  0,  3,  2, 10,  1, 12, -2, 11,  1,  2,  5,  2, -7,  3,
  0,  3,  1, 10,  1, 13, -2, 11,  0,  2,  2,  2, -2,  3,  0,  2,  5,  3, -7,
  4,  0,  3,  1, 12, -2, 13,  2, 11,  0,  2,  4,  3, -5,  4,  0,  2,  3,  3,
 -3,  4,  0,  1,  1,  2,  0,  3,  3, 10,  1, 12, -3, 13,  0,  2,  2,  3, -4,
  5,  0,  2,  2,  3, -3,  5,  0,  2,  2, 10, -2, 13,  0,  2,  2,  3, -2,  5,
  0,  2,  3,  2, -3,  3,  0,  3,  1, 10, -1, 12, -1, 13,  1,  2,  2,  3, -1,
  5,  0,  2,  2,  3, -2,  6,  0,  1,  2, 12,  2,  3, -2, 10,  1, 11,  1, 14,
  0,  2,  2, 10, -2, 11,  0,  2,  2,  2, -1,  3,  0,  4, -2, 10,  2, 13,  1,
  2, -1,  3,  0,  2,  4,  2, -4,  3,  0,  2,  3, 10, -3, 13,  0,  4, -2, 10,
  2, 13,  1,  3, -1,  5,  0,  2,  3,  3, -3,  5,  0,  3,  2, 10, -1, 12, -2,
 13,  2,  3,  3, 10, -1, 13, -2, 11,  0,  1,  3, 12,  1,  4, -2, 10,  2, 13,
  2,  2, -2,  3,  0,  3,  2, 10, -1, 12, -2, 11,  1,  2,  5,  2, -5,  3,  0,
  2,  4, 10, -4, 13,  0,  2,  6,  2, -6,  3,  0,  3,  2, 10, -2, 12, -2, 13,
  1,  3,  4, 10, -2, 13, -2, 11,  0,  3,  2, 10, -2, 12, -2, 11,  0,  2,  7,
  2, -7,  3,  0,  3,  2, 10, -3, 12, -2, 13,  0,  2,  8,  2, -8,  3,  0,  2,
  9,  2, -9,  3,  0,  2, 10,  2,-10,  3,  0,  3,  2, 10, -4, 12, -1, 13,  0,
  3,  4, 10, -2, 12, -3, 13,  0,  4,  4, 10, -1, 12, -1, 13, -2, 11,  0,  3,
  2, 10, -3, 12, -1, 13,  1,  4, -2, 10,  1, 13,  3,  3, -2,  5,  0,  3,  4,
 10, -1, 12, -3, 13,  0,  4, -2, 10,  1, 13,  3,  3, -3,  5,  0,  4,  2, 10,
 -2, 12,  1, 13, -2, 11,  0,  4, -2, 10,  1, 13,  2,  2, -1,  3,  0,  3,  3,
 10, -1, 12, -2, 11,  0,  3,  4, 10, -1, 13, -2, 11,  0,  3,  2, 10, -2, 12,
 -1, 13,  2,  4, -2, 10,  1, 13,  2,  3, -1,  5,  0,  3,  3, 10, -1, 12, -2,
 13,  0,  4, -2, 10,  1, 13,  3,  2, -3,  3,  0,  4, -2, 10,  1, 13,  2,  3,
 -2,  5,  0,  2,  4, 10, -3, 13,  0,  4, -2, 10,  1, 13,  2,  3, -3,  5,  0,
  3, -2, 10,  1, 13,  1,  2,  0,  4,  2, 10, -1, 12,  1, 13, -2, 11,  1,  4,
 -2, 10,  1, 13,  2,  2, -2,  3,  0,  2,  3, 12, -1, 13,  0,  2,  3, 10, -2,
 11,  0,  2,  1, 10, -2, 12,  0,  4,  4, 10,  1, 12, -1, 13, -2, 11,  0,  3,
 -1, 13,  3,  2, -2,  3,  0,  3, -1, 13,  3,  3, -2,  5,  0,  3, -2, 10, 18,
  2,-15,  3,  0,  5,  2, 10, -1, 13,  3,  3, -8,  4,  3,  5,  0,  3,  2, 10,
 -1, 12, -1, 13,  2,  5, -2, 10,  1, 13,  5,  3, -8,  4,  3,  5,  0,  5, -2,
 10,  1, 13,  1,  3,  2,  5, -5,  6,  0,  4,  2, 10, -2, 13, 18,  2,-17,  3,
  0,  4, -2, 10,  1, 13,  1,  3, -1,  6,  0,  4, -2, 10,  1, 13,  2,  3, -2,
  4,  0,  4, -2, 10,  1, 13,  1,  3, -1,  5,  0,  2,  3, 10, -2, 13,  0,  4,
 -2, 10,  1, 13,  3,  2, -4,  3,  0,  4, -2, 10,  1, 13,  3,  3, -4,  4,  0,
  4, -2, 10,  1, 13,  1,  3, -2,  5,  0,  3,  4, 10,  1, 12, -3, 13,  0,  4,
 -2, 10,  1, 13,  1,  3, -3,  5,  0,  3, -1, 13,  4,  2, -4,  3,  0,  4, -2,
 10,  1, 13,  1,  2, -1,  3,  0,  4, -2, 10,  1, 13,  1,  3, -1,  4,  0,  4,
 -2, 10,  1, 13,  2,  3, -3,  4,  0,  4, -2, 10,  1, 13,  3,  3, -5,  4,  0,
  3,  2, 10,  1, 13, -2, 11,  0,  4, -2, 10, -1, 13,  1, 11,  1, 14,  0,  4,
 -2, 10,  1, 13,  2,  2, -3,  3,  1,  2,  2, 12, -1, 13,  1,  3,  3, 10,  1,
 12, -2, 11,  0,  4,  2, 10, -1, 13,  2,  3, -4,  4,  0,  4,  2, 10, -1, 13,
  3,  2, -5,  3,  0,  2,  1, 10, -1, 12,  1,  3, -1, 13,  3,  2, -3,  3,  0,
  3, -2, 10,  1, 13,  1,  5,  0,  4,  2, 10, -1, 13,  1,  3, -2,  4,  0,  3,
 -1, 13,  2,  3, -2,  5,  0,  4,  2, 10, -1, 13, -1, 11,  1, 14,  0,  3, -1,
 13,  5,  3, -6,  4,  0,  3, -2, 10,  1, 13,  1,  6,  0,  3, -1, 10,  1,  3,
 -1,  5,  0,  4, -2, 10,  1, 13,  8,  2,-13,  3,  1,  3, -2, 10, 18,  2,-16,
  3,  1,  5, -2, 10,  1, 13,  3,  2, -7,  3,  4,  4,  1,  4,  2, 10, -1, 13,
  2,  5, -5,  6,  1,  5,  2, 10, -1, 13,  4,  3, -8,  4,  3,  5,  1,  2,  2,
 10, -1, 13,  2,  5, -2, 10,  1, 13,  4,  3, -8,  4,  3,  5,  1,  4, -2, 10,
  1, 13,  2,  5, -5,  6,  1,  5,  2, 10, -1, 13,  3,  2, -7,  3,  4,  4,  0,
  4,  2, 10, -2, 13, 18,  2,-16,  3,  1,  4,  2, 10, -1, 13,  8,  2,-13,  3,
  1,  3, -1, 10,  3,  2, -4,  3,  0,  3, -1, 13,  6,  2, -8,  3,  0,  3, -1,
 13,  2,  3, -3,  5,  0,  3, -1, 13,  6,  3, -8,  4,  0,  3,  2, 10, -1, 13,
  1,  6,  0,  4, -2, 10,  1, 13, -1, 11,  1, 14,  0,  4, -2, 10,  1, 13,  1,
  3, -2,  4,  0,  3,  2, 10, -1, 13,  1,  5,  0,  3,  3, 10,  1, 12, -2, 13,
  0,  4, -2, 10,  1, 13,  3,  2, -5,  3,  0,  4, -2, 10,  1, 13,  2,  3, -4,
  4,  0,  2, -1, 13,  1,  2,  0,  4,  2, 10, -1, 13,  2,  2, -3,  3,  0,  3,
 -1, 10,  1,  2, -1,  3,  0,  3, -1, 13,  4,  2, -5,  3,  0,  3,  2, 10, -3,
 13,  2, 11,  0,  4,  2, 10, -1, 13,  2,  3, -3,  4,  0,  3, -1, 13,  2,  2,
 -2,  3,  0,  4,  2, 10, -1, 13,  1,  2, -1,  3,  0,  4,  2, 10,  1, 12,  1,
 13, -2, 11,  0,  3, -2, 13, 18,  2,-15,  3,  0,  2,  1, 12, -1, 13,  2,  3,
 -1, 13,  1,  3, -1,  6,  0,  4,  2, 10, -1, 13,  1,  3, -2,  5,  0,  3, -1,
 13,  2,  3, -2,  4,  0,  3, -1, 13,  1,  3, -1,  5,  0,  4,  2, 10, -1, 13,
  3,  3, -4,  4,  0,  1,  1, 10,  0,  3, -1, 13,  3,  2, -4,  3,  0,  3, -1,
 13,  3,  3, -4,  4,  0,  4,  2, 10, -1, 13,  1,  3, -1,  5,  0,  4,  2, 10,
 -1, 13,  2,  3, -2,  4,  0,  3, -1, 13,  1,  3, -2,  5,  0,  3,  2, 10,  1,
 12, -1, 13,  2,  3,  1, 12,  1, 13, -2, 11,  0,  3, -1, 13,  1,  2, -1,  3,
  0,  4,  2, 10, -1, 13,  2,  2, -2,  3,  0,  3, -1, 13,  4,  2, -6,  3,  0,
  3, -1, 13,  2,  3, -3,  4,  0,  3,  1, 13,  1,  2, -2,  3,  0,  4,  2, 10,
 -1, 13,  3,  3, -3,  4,  0,  2,  3, 13, -2, 11,  0,  4,  2, 10, -1, 13,  4,
  2, -5,  3,  0,  3,  1, 10,  1,  2, -1,  3,  0,  3, -1, 13,  2,  2, -3,  3,
  1,  3,  2, 10,  2, 12, -3, 13,  0,  3,  2, 10, -1, 13,  1,  2,  0,  3,  1,
 13,  2,  3, -4,  4,  0,  3,  1, 13,  3,  2, -5,  3,  0,  2, 21,  2,-21,  3,
  0,  3,  1, 10,  1, 12, -2, 13,  1,  4,  2, 10, -1, 13,  2,  3, -4,  5,  0,
  4,  2, 10, -1, 13,  7,  3,-10,  4,  0,  2, -1, 13,  1,  5,  0,  3,  1, 13,
  1,  3, -2,  4,  0,  4,  2, 10, -3, 13,  2,  3, -2,  5,  0,  3,  1, 10,  1,
  3, -2,  5,  0,  3,  1, 13, -1, 11,  1, 14,  1,  2, -1, 13,  1,  6,  0,  4,
  2, 10, -1, 13,  6,  3, -8,  4,  1,  4,  2, 10, -1, 13,  2,  3, -3,  5,  1,
  3, -1, 13,  8,  3,-15,  4,  0,  4,  2, 10, -1, 13,  6,  2, -8,  3,  0,  5,
  2, 10, -1, 13, -2, 11,  5,  2, -6,  3,  0,  3,  1, 10,  3,  3, -4,  4,  0,
  3,  1, 10,  3,  2, -4,  3,  1,  4,  1, 10, -1, 13, -1, 11,  2,  4,  0,  3,
 -2, 13, 26,  2,-29,  3,  0,  3, -1, 13,  8,  2,-13,  3,  0,  3, -2, 13, 18,
  2,-16,  3,  2,  4, -1, 13,  3,  2, -7,  3,  4,  4,  0,  3,  1, 13,  2,  5,
 -5,  6,  1,  4,  1, 13,  4,  3, -8,  4,  3,  5,  1,  1,  1, 13,  3,  4, -1,
 13,  4,  3, -8,  4,  3,  5,  1,  3, -1, 13,  2,  5, -5,  6,  1,  4,  1, 13,
  3,  2, -7,  3,  4,  4,  0,  2, 18,  2,-16,  3,  1,  3,  1, 13,  8,  2,-13,
  3,  2,  2, 26,  2,-29,  3,  0,  4,  1, 10,  1, 13, -1, 11,  2,  4,  0,  5,
  2, 10,  1, 13, -2, 11,  5,  2, -6,  3,  0,  3,  1, 13,  8,  3,-15,  4,  1,
  4,  2, 10, -3, 13,  2,  3, -3,  5,  0,  3,  1, 10,  1,  3, -1,  5,  0,  2,
  1, 13,  1,  6,  0,  4,  2, 10, -1, 13,  5,  3, -6,  4,  0,  3,  1, 10,  2,
  3, -2,  4,  0,  3, -1, 13, -1, 11,  1, 14,  1,  4,  2, 10, -1, 13,  2,  3,
 -5,  6,  0,  4,  2, 10, -1, 13,  2,  3, -2,  5,  0,  5,  2, 10, -1, 13,  2,
  3, -4,  5,  5,  6,  0,  3, -1, 13,  1,  3, -2,  4,  1,  2,  1, 13,  1,  5,
  0,  4,  2, 10, -1, 13,  4,  3, -4,  4,  0,  4,  2, 10, -1, 13,  3,  2, -3,
  3,  0,  4,  2, 10,  2, 12, -1, 13, -2, 11,  0,  2,  1, 10,  1, 12,  2,  3,
 -1, 13,  3,  2, -5,  3,  0,  3, -1, 13,  2,  3, -4,  4,  0,  4,  2, 10, -1,
 13,  2,  3, -1,  5,  0,  4,  2, 10, -1, 13,  2,  3, -2,  6,  0,  3,  1, 10,
  1, 12, -2, 11,  0,  3,  2, 10,  2, 12, -1, 13,  1,  3,  1, 13,  2,  2, -3,
  3,  1,  3, -1, 13,  1, 11,  1, 14,  0,  2,  1, 13, -2, 11,  0,  4,  2, 10,
 -1, 13,  5,  2, -6,  3,  0,  3, -1, 13,  1,  2, -2,  3,  0,  3,  1, 13,  2,
  3, -3,  4,  0,  3,  1, 13,  1,  2, -1,  3,  0,  4,  2, 10, -1, 13,  4,  2,
 -4,  3,  0,  3,  2, 10,  1, 12, -3, 13,  1,  3,  1, 13,  1,  3, -2,  5,  0,
  3,  1, 13,  3,  3, -4,  4,  0,  3,  1, 13,  3,  2, -4,  3,  0,  2,  1, 10,
 -2, 13,  0,  4,  2, 10, -1, 13,  3,  3, -4,  5,  0,  3,  1, 13,  1,  3, -1,
  5,  0,  3,  1, 13,  2,  3, -2,  4,  0,  3,  1, 13,  1,  3, -1,  6,  0,  4,
  2, 10, -1, 13,  3,  3, -3,  5,  0,  4,  2, 10, -1, 13,  6,  2, -7,  3,  0,
  2,  1, 12,  1, 13,  2,  4,  2, 10, -1, 13,  3,  3, -2,  5,  0,  4,  2, 10,
  1, 12, -1, 13, -2, 11,  0,  2,  1, 10,  2, 12,  0,  2,  1, 10, -2, 11,  0,
  3,  1, 13,  2,  2, -2,  3,  0,  3,  1, 12, -1, 13,  2, 11,  0,  4,  2, 10,
 -1, 13,  5,  2, -5,  3,  0,  3,  1, 13,  2,  3, -3,  5,  0,  2,  2, 10, -3,
 13,  0,  3,  1, 13,  2,  3, -2,  5,  0,  3,  1, 13,  3,  2, -3,  3,  0,  3,
  1, 10, -1, 12, -2, 13,  0,  4,  2, 10, -1, 13,  6,  2, -6,  3,  0,  2,  2,
 12,  1, 13,  1,  3,  2, 10, -1, 13, -2, 11,  0,  3,  1, 10, -1, 12, -2, 11,
  0,  3,  2, 10,  1, 13, -4, 11,  0,  3,  1, 13,  4,  2, -4,  3,  0,  4,  2,
 10, -1, 13,  7,  2, -7,  3,  0,  3,  2, 10, -1, 12, -3, 13,  1,  2,  3, 12,
  1, 13,  0,  4,  2, 10, -1, 12, -1, 13, -2, 11,  0,  3,  1, 13,  5,  2, -5,
  3,  0,  4,  2, 10, -1, 13,  8,  2, -8,  3,  0,  3,  2, 10, -2, 12, -3, 13,
  0,  4,  2, 10, -1, 13,  9,  2, -9,  3,  0,  3,  4, 10, -3, 12, -2, 13,  0,
  2,  2, 10, -4, 12,  0,  3,  4, 10, -2, 12, -2, 13,  1,  2,  6, 10, -4, 13,
  0,  3,  4, 10, -1, 12, -2, 11,  0,  2,  2, 10, -3, 12,  1,  3,  3, 10, -2,
 12, -1, 13,  0,  3, -2, 10,  3,  3, -2,  5,  0,  3,  4, 10, -1, 12, -2, 13,
  1,  3, -2, 10,  3,  3, -3,  5,  0,  2,  5, 10, -3, 13,  0,  3, -2, 10,  4,
  2, -4,  3,  0,  3, -2, 10,  2,  2, -1,  3,  0,  2,  4, 10, -2, 11,  0,  2,
  2, 10, -2, 12,  2,  3, -2, 10,  3,  3, -2,  4,  0,  3, -2, 10,  2,  3, -1,
  5,  0,  3,  3, 10, -1, 12, -1, 13,  1,  3, -2, 10,  3,  2, -3,  3,  0,  3,
 -2, 10,  2,  3, -2,  5,  0,  2,  4, 10, -2, 13,  0,  3, -2, 10,  2,  3, -3,
  5,  0,  2, -2, 10,  1,  2,  0,  4,  2, 10, -1, 12,  2, 13, -2, 11,  0,  3,
 -2, 10,  2,  2, -2,  3,  0,  3,  3, 10,  1, 13, -2, 11,  0,  3,  4, 10,  1,
 12, -2, 11,  0,  4,  2, 10, -1, 12, -1, 11,  1, 14,  0,  4, -2, 10, -1, 13,
 18,  2,-15,  3,  0,  4,  2, 10,  3,  3, -8,  4,  3,  5,  0,  2,  2, 10, -1,
 12,  2,  4, -2, 10,  5,  3, -8,  4,  3,  5,  0,  4,  2, 10, -1, 13, 18,  2,
-17,  3,  0,  3, -2, 10,  1,  3, -1,  6,  0,  3, -2, 10,  2,  3, -2,  4,  0,
  3, -2, 10,  1,  3, -1,  5,  0,  2,  3, 10, -1, 13,  0,  3, -2, 10,  3,  2,
 -4,  3,  0,  3, -2, 10,  3,  3, -4,  4,  0,  3, -2, 10,  1,  3, -2,  5,  0,
  3,  4, 10,  1, 12, -2, 13,  1,  4,  2, 10, -1, 12, -2, 13,  2, 11,  0,  3,
 -2, 10,  1,  2, -1,  3,  0,  3, -2, 10,  2,  3, -3,  4,  0,  3,  2, 10,  2,
 13, -2, 11,  0,  3, -2, 10,  2,  2, -3,  3,  0,  2,  2, 12, -2, 13,  1,  3,
  2, 10,  2,  3, -4,  4,  0,  3,  2, 10,  3,  2, -5,  3,  0,  3,  1, 10, -1,
 12,  1, 13,  1,  3, -2, 13,  3,  2, -3,  3,  0,  2, -2, 10,  1,  5,  0,  3,
  2, 10,  1,  3, -2,  4,  0,  3, -2, 13,  2,  3, -2,  5,  0,  3,  2, 10, -1,
 11,  1, 14,  0,  4,  4, 10, -2, 13,  2,  3, -3,  5,  0,  3, -2, 10,  8,  2,
-13,  3,  0,  4, -2, 10, -1, 13, 18,  2,-16,  3,  1,  4, -2, 10,  3,  2, -7,
  3,  4,  4,  0,  4,  2, 10,  4,  3, -8,  4,  3,  5,  1,  1,  2, 10,  3,  4,
 -2, 10,  4,  3, -8,  4,  3,  5,  1,  4,  2, 10,  3,  2, -7,  3,  4,  4,  0,
  4,  2, 10, -1, 13, 18,  2,-16,  3,  1,  3,  2, 10,  8,  2,-13,  3,  0,  3,
 -2, 10, -1, 11,  1, 14,  0,  4,  4, 10, -2, 13,  2,  3, -2,  5,  0,  3, -2,
 10,  1,  3, -2,  4,  0,  2,  2, 10,  1,  5,  0,  4,  4, 10, -2, 13,  3,  2,
 -3,  3,  0,  3,  3, 10,  1, 12, -1, 13,  1,  3, -2, 10,  3,  2, -5,  3,  0,
  3, -2, 10,  2,  3, -4,  4,  0,  3,  4, 10,  2, 12, -2, 13,  0,  3,  2, 10,
  2,  2, -3,  3,  0,  3,  2, 10, -2, 13,  2, 11,  0,  3,  2, 10,  1,  2, -1,
  3,  0,  4,  2, 10,  1, 12,  2, 13, -2, 11,  0,  2,  1, 12, -2, 13,  2,  3,
  2, 10,  1,  3, -2,  5,  0,  3, -2, 13,  1,  3, -1,  5,  0,  3,  2, 10,  3,
  2, -4,  3,  0,  2,  1, 10,  1, 13,  0,  3,  2, 10,  1,  3, -1,  5,  0,  3,
  2, 10,  2,  3, -2,  4,  0,  2,  2, 10,  1, 12,  2,  2,  1, 12, -2, 11,  0,
  3, -2, 13,  1,  2, -1,  3,  0,  3,  1, 10, -1, 13,  2, 11,  0,  3,  2, 10,
  2,  2, -2,  3,  0,  3,  1, 10,  1, 12, -3, 13,  0,  3,  2, 13, -1, 11,  1,
 14,  0,  3,  2, 10,  2,  3, -3,  5,  0,  3,  2, 10,  6,  2, -8,  3,  0,  3,
 -3, 13, 18,  2,-16,  3,  1,  3,  2, 13,  2,  5, -5,  6,  0,  4,  2, 13,  4,
  3, -8,  4,  3,  5,  0,  1,  2, 13,  0,  4, -2, 13,  4,  3, -8,  4,  3,  5,
  0,  3, -2, 13,  2,  5, -5,  6,  0,  3,  1, 13, 18,  2,-16,  3,  1,  3, -2,
 13, -1, 11,  1, 14,  0,  3,  2, 10,  2,  3, -2,  5,  0,  3,  2, 10,  3,  2,
 -3,  3,  0,  3,  1, 10,  1, 12,  1, 13,  1,  2,  2, 10,  2, 12,  1,  2,  1,
 11,  1, 14,  1,  4, -1, 13, -2, 11, 18,  2,-16,  3,  0,  1,  2, 11,  0,  4,
 -1, 13,  2, 11, 18,  2,-16,  3,  0,  2, -3, 11,  1, 14,  0,  3,  2, 13,  1,
  2, -1,  3,  0,  3,  2, 10,  4,  2, -4,  3,  0,  3,  2, 10,  1, 12, -4, 13,
  0,  2,  1, 10, -3, 13,  0,  3,  2, 13,  1,  3, -1,  5,  0,  2,  1, 12,  2,
 13,  2,  3,  1, 10,  2, 12,  1, 13,  0,  3,  1, 10, -1, 13, -2, 11,  0,  2,
  1, 12,  2, 11,  1,  3,  2, 10,  5,  2, -5,  3,  0,  2,  2, 10, -4, 13,  0,
  3,  2, 10,  6,  2, -6,  3,  0,  2,  2, 12,  2, 13,  0,  3,  2, 10, -2, 13,
 -2, 11,  0,  2,  2, 12,  2, 11,  0,  2,  2, 10, -4, 11,  0,  3,  2, 10,  7,
  2, -7,  3,  0,  3,  2, 10, -1, 12, -4, 13,  0,  4,  2, 10, -1, 12, -2, 13,
 -2, 11,  0,  3,  2, 10,  8,  2, -8,  3,  0,  3,  2, 10,  9,  2, -9,  3,  0,
  3,  4, 10, -3, 12, -1, 13,  0,  3,  6, 10, -1, 12, -3, 13,  0,  3,  4, 10,
 -2, 12, -1, 13,  1,  3,  5, 10, -1, 12, -2, 13,  0,  2,  6, 10, -3, 13,  0,
  4,  4, 10, -1, 12,  1, 13, -2, 11,  0,  3,  2, 10, -3, 12,  1, 13,  0,  2,
  3, 10, -2, 12,  0,  3,  4, 10, -1, 12, -1, 13,  1,  2,  5, 10, -2, 13,  0,
  3,  6, 10,  1, 12, -3, 13,  0,  3,  4, 10,  1, 13, -2, 11,  0,  3,  2, 10,
 -2, 12,  1, 13,  1,  2,  3, 10, -1, 12,  0,  4, -2, 10, -1, 13,  2,  3, -2,
  5,  0,  2,  4, 10, -1, 13,  0,  4,  2, 10, -2, 12, -1, 13,  2, 11,  0,  3,
  4, 10, -3, 13,  2, 11,  0,  4, -2, 10, -1, 13,  2,  2, -2,  3,  0,  3,  2,
 10, -1, 12,  1, 13,  2,  4, -2, 10, -1, 13,  1,  3, -1,  5,  0,  1,  3, 10,
  0,  3,  4, 10,  1, 12, -1, 13,  1,  4,  2, 10, -1, 12, -1, 13,  2, 11,  1,
  4, -2, 10, -1, 13,  1,  2, -1,  3,  0,  3,  2, 10,  3, 13, -2, 11,  0,  2,
  2, 12, -3, 13,  0,  3,  1, 10, -1, 12,  2, 13,  0,  4,  2, 10,  1, 13, -1,
 11,  1, 14,  0,  4, -2, 10, -2, 13, 18,  2,-16,  3,  0,  5,  2, 10,  1, 13,
  4,  3, -8,  4,  3,  5,  0,  2,  2, 10,  1, 13,  1,  5, -2, 10, -1, 13,  4,
  3, -8,  4,  3,  5,  0,  3,  2, 10, 18,  2,-16,  3,  0,  4, -2, 10, -1, 13,
 -1, 11,  1, 14,  0,  4,  4, 10, -1, 13,  2,  3, -2,  5,  0,  4,  4, 10, -1,
 13,  3,  2, -3,  3,  0,  2,  3, 10,  1, 12,  1,  3,  4, 10,  2, 12, -1, 13,
  0,  4,  2, 10, -1, 13,  1, 11,  1, 14,  0,  3,  2, 10, -1, 13,  2, 11,  0,
  2,  1, 12, -3, 13,  1,  2,  1, 10,  2, 13,  0,  3,  2, 10,  1, 12,  1, 13,
  1,  3,  1, 12, -1, 13, -2, 11,  1,  2,  1, 10,  2, 11,  0,  4,  2, 10,  1,
 12, -1, 13,  2, 11,  0,  1,  3, 13,  0,  4,  2, 10,  1, 13,  2,  3, -2,  5,
  0,  3,  1, 10,  1, 12,  2, 13,  0,  3,  2, 10,  2, 12,  1, 13,  0,  3,  1,
 13,  1, 11,  1, 14,  0,  2,  1, 13,  2, 11,  0,  3,  1, 10,  1, 12,  2, 11,
  0,  4,  2, 10,  2, 12, -1, 13,  2, 11,  0,  2,  1, 13, -4, 11,  0,  2,  1,
 10, -4, 13,  0,  2,  1, 12,  3, 13,  1,  3,  1, 12,  1, 13,  2, 11,  1,  2,
  2, 10, -5, 13,  0,  3,  2, 10, -3, 13, -2, 11,  0,  3,  2, 10, -1, 13, -4,
 11,  0,  3,  6, 10, -2, 12, -2, 13,  0,  2,  4, 10, -3, 12,  0,  3,  6, 10,
 -1, 12, -2, 13,  0,  2,  4, 10, -2, 12,  1,  2,  6, 10, -2, 13,  0,  2,  4,
 10, -1, 12,  1,  2,  5, 10, -1, 13,  0,  3,  6, 10,  1, 12, -2, 13,  0,  4,
  4, 10, -1, 12, -2, 13,  2, 11,  0,  3,  4, 10,  2, 13, -2, 11,  0,  3,  2,
 10, -2, 12,  2, 13,  0,  1,  4, 10,  0,  3,  2, 10, -2, 12,  2, 11,  0,  3,
  4, 10, -2, 13,  2, 11,  0,  3,  2, 10, -1, 12,  2, 13,  1,  2,  3, 10,  1,
 13,  0,  2,  4, 10,  1, 12,  1,  3,  2, 10, -1, 12,  2, 11,  1,  3,  3, 10,
 -1, 13,  2, 11,  0,  2,  2, 10,  2, 13,  0,  3,  3, 10,  1, 12,  1, 13,  0,
  3,  2, 10,  1, 11,  1, 14,  0,  2,  2, 10,  2, 11,  0,  2,  1, 12, -4, 13,
  0,  2,  1, 10,  3, 13,  0,  3,  2, 10,  1, 12,  2, 13,  1,  3,  1, 12, -2,
 13, -2, 11,  0,  3,  1, 10,  1, 13,  2, 11,  0,  3,  2, 10,  1, 12,  2, 11,
  0,  1,  4, 13,  0,  3,  1, 10,  1, 12,  3, 13,  0,  2,  2, 13,  2, 11,  0,
  4,  1, 10,  1, 12,  1, 13,  2, 11,  0,  1,  4, 11,  0,  2,  1, 12,  4, 13,
  0,  3,  1, 12,  2, 13,  2, 11,  0,  3,  2, 10, -4, 13, -2, 11,  0,  3,  6,
 10, -2, 12, -1, 13,  0,  2,  8, 10, -3, 13,  0,  3,  6, 10, -1, 12, -1, 13,
  0,  3,  4, 10, -2, 12,  1, 13,  0,  2,  6, 10, -1, 13,  0,  3,  4, 10, -1,
 12,  1, 13,  1,  3,  6, 10,  1, 12, -1, 13,  0,  4,  4, 10, -1, 12, -1, 13,
  2, 11,  0,  3,  2, 10, -2, 12,  3, 13,  0,  2,  4, 10,  1, 13,  0,  3,  4,
 10, -1, 13,  2, 11,  0,  3,  2, 10, -1, 12,  3, 13,  0,  3,  4, 10,  1, 12,
  1, 13,  0,  4,  2, 10, -1, 12,  1, 13,  2, 11,  0,  2,  2, 10,  3, 13,  0,
  3,  2, 10,  1, 13,  2, 11,  0,  3,  2, 10, -1, 13,  4, 11,  0,  3,  2, 10,
  1, 12,  3, 13,  0,  3,  1, 12, -3, 13, -2, 11,  0,  3,  1, 10,  2, 13,  2,
 11,  0,  4,  2, 10,  1, 12,  1, 13,  2, 11,  0,  1,  5, 13,  0,  2,  3, 13,
  2, 11,  0,  2,  1, 13,  4, 11,  0,  3,  1, 12,  3, 13,  2, 11,  0,  2,  8,
 10, -2, 13,  0,  2,  6, 10, -1, 12,  0,  1,  6, 10,  0,  3,  6, 10, -2, 13,
  2, 11,  0,  3,  4, 10, -1, 12,  2, 13,  0,  3,  4, 10, -1, 12,  2, 11,  0,
  2,  4, 10,  2, 13,  0,  2,  4, 10,  2, 11,  0,  3,  2, 10, -1, 12,  4, 13,
  0,  3,  4, 10,  1, 12,  2, 13,  0,  4,  2, 10, -1, 12,  2, 13,  2, 11,  0,
  2,  2, 10,  4, 13,  0,  3,  2, 10,  2, 13,  2, 11,  0,  2,  2, 10,  4, 11,
  0,  1,  6, 13,  0,  2,  4, 13,  2, 11,  0,  2,  2, 13,  4, 11,  0,  3,  6,
 10, -1, 12,  1, 13,  0,  2,  6, 10,  1, 13,  0,  2,  4, 10,  3, 13,  0,  3,
  4, 10,  1, 13,  2, 11,  0,  2,  2, 10,  5, 13,  0,  3,  2, 10,  3, 13,  2,
 11,  0, -1);

RDA: double = 4.8481368110953599359e-6;
PI2: double = 6.2831853071795864769;
freqs: array[0..8] of double =
(53810162868.8982,21066413643.3548,12959774228.3429,6890507749.3988,
1092566037.7991,439960985.5372,154248119.3933,78655032.0744,52272245.1795);
phases: array[0..8] of double =
(908103.259872,655127.28306,361679.244588,1279558.798488,123665.467464,
180278.79948,1130598.018396,1095655.195728,860492.1546);
max_armonic: array[0..8,0..8] of byte =
((11, 14, 10, 11,  4,  5,  2,  0,  0),(  5, 14, 13,  8,  4,  5,  1,  0,  0),
(  1,  9, 14, 17,  5,  5,  2,  1,  0),(  0,  5, 12, 24,  9,  7,  3,  2,  0),
(  0,  0,  1,  0,  9, 16,  7,  5,  0),(  0,  0,  1,  0,  8, 18,  9,  5,  0),
(  0,  0,  0,  0,  5, 10,  9, 12,  0),(  0,  0,  0,  0,  3,  8,  7,  9,  0),
(  0,  0,  0,  0,  2,  2,  9, 13, 13));
max_armonic_mlr: array [0..13] of byte = (3,26,29,23,5,10,0,0,0,8,4,4,6,2);
max_armonic_mlat: array [0..13] of byte = (0,26,29,8,3,5,0,0,0,6,5,3,5,1);
distance: array [0..8] of double =
(3.8709830979999998e-01,7.2332982000000001e-01,1.5303348827100001e+00,
5.2026032092000003e+00,9.5575813548599999e+00,1.9218446061800002e+01,
3.0110386869399999e+01,3.9539999999999999e+01,2.5735686895300000e-03);
kx0 = 623; kx1 = 379; kx2 = 144; kx3 = 23; kx4 = 11; kx5 = 4;
ky0 = 184; ky1 = 134; ky2 = 62;  ky3 = 14; ky4 = 6;  ky5 = 2;
kz0 = 523; kz1 = 290; kz2 = 134; kz3 = 20; kz4 = 9;  kz5 = 2;

TYPE

asx0 = array[1..kx0,1..3] of double; asx1 = array[1..kx1,1..3] of double;
asx2 = array[1..kx2,1..3] of double; asx3 = array[1..kx3,1..3] of double;
asx4 = array[1..kx4,1..3] of double; asx5 = array[1..kx5,1..3] of double;
asy0 = array[1..ky0,1..3] of double; asy1 = array[1..ky1,1..3] of double;
asy2 = array[1..ky2,1..3] of double; asy3 = array[1..ky3,1..3] of double;
asy4 = array[1..ky4,1..3] of double; asy5 = array[1..ky5,1..3] of double;
asz0 = array[1..kz0,1..3] of double; asz1 = array[1..kz1,1..3] of double;
asz2 = array[1..kz2,1..3] of double; asz3 = array[1..kz3,1..3] of double;
asz4 = array[1..kz4,1..3] of double; asz5 = array[1..kz5,1..3] of double;
mertabl = array[0..399] of double; mertabb = array[0..399] of double;
mertabr = array[0..399] of double; ventabl = array[0..283] of double;
ventabb = array[0..283] of double; ventabr = array[0..283] of double;
martabl = array[0..676] of double; martabb = array[0..676] of double;
martabr = array[0..676] of double; juptabl = array[0..594] of double;
juptabb = array[0..594] of double; juptabr = array[0..594] of double;
sattabl = array[0..787] of double; sattabb = array[0..787] of double;
sattabr = array[0..787] of double; uratabl = array[0..531] of double;
uratabb = array[0..531] of double; uratabr = array[0..531] of double;
neptabl = array[0..161] of double; neptabb = array[0..161] of double;
neptabr = array[0..161] of double; plutabl = array[0..603] of double;
plutabb = array[0..603] of double; plutabr = array[0..603] of double;
mlattabl = array[0..849] of double; mlrtabl = array[0..1561] of double;
mlrtabr = array[0..1561] of double;

VAR

psx0: ^asx0; psx1: ^asx1; psx2: ^asx2; psx3: ^asx3; psx4: ^asx4; psx5: ^asx5;
psy0: ^asy0; psy1: ^asy1; psy2: ^asy2; psy3: ^asy3; psy4: ^asy4; psy5: ^asy5;
psz0: ^asz0; psz1: ^asz1; psz2: ^asz2; psz3: ^asz3; psz4: ^asz4; psz5: ^asz5;
pmertabl: ^mertabl; pmertabb: ^mertabb; pmertabr: ^mertabr; pventabl: ^ventabl;
pventabb: ^ventabb; pventabr: ^ventabr; pmartabl: ^martabl; pmartabb: ^martabb;
pmartabr: ^martabr; pjuptabl: ^juptabl; pjuptabb: ^juptabb; pjuptabr: ^juptabr;
psattabl: ^sattabl; psattabb: ^sattabb; psattabr: ^sattabr; puratabl: ^uratabl;
puratabb: ^uratabb; puratabr: ^uratabr; pneptabl: ^neptabl; pneptabb: ^neptabb;
pneptabr: ^neptabr; pplutabl: ^plutabl; pplutabb: ^plutabb; pplutabr: ^plutabr;
pmlattabl: ^mlattabl; pmlrtabl: ^mlrtabl; pmlrtabr: ^mlrtabr;
mx0,mx1,mx2,mx3,mx4,mx5: extended;
my0,my1,my2,my3,my4,my5: extended;
mz0,mz1,mz2,mz3,mz4,mz5: extended;
ft : file of double;
ss : array [0..13,0..28] of double;
cc : array [0..13,0..28] of double;
args: array [0..13] of double;
i,jp,k,m,k1,ip,np,nt,sci: integer;
p,pl,pb,pr: longint;
acu,asu,acv,asv,s,su,cu,sv,cv,t,cul,cub,cur,sul,sub,sur,ta,sl,sb,sr: double;
temp,lp_equinox,x,t2 : double;

PROCEDURE pla_getdatamem;
BEGIN
new(psx0); new(psx1); new(psx2); new(psx3); new(psx4); new(psx5);
new(psy0); new(psy1); new(psy2); new(psy3); new(psy4); new(psy5);
new(psz0); new(psz1); new(psz2); new(psz3); new(psz4); new(psz5);
new(pmertabl); new(pmertabb); new(pmertabr); new(pventabl); new(pventabb);
new(pventabr); new(pmartabl); new(pmartabb); new(pmartabr); new(pjuptabl);
new(pjuptabb); new(pjuptabr); new(psattabl); new(psattabb); new(psattabr);
new(puratabl); new(puratabb); new(puratabr); new(pneptabl); new(pneptabb);
new(pneptabr); new(pplutabl); new(pplutabb); new(pplutabr); new(pmlattabl);
new(pmlrtabl); new(pmlrtabr);
assign(ft,'tabplar.ttb');
reset(ft);
for i:=0 to 399 do read(ft,pmertabl^[i],pmertabb^[i],pmertabr^[i]);
for i:=0 to 283 do read(ft,pventabl^[i],pventabb^[i],pventabr^[i]);
for i:=0 to 676 do read(ft,pmartabl^[i],pmartabb^[i],pmartabr^[i]);
for i:=0 to 594 do read(ft,pjuptabl^[i],pjuptabb^[i],pjuptabr^[i]);
for i:=0 to 787 do read(ft,psattabl^[i],psattabb^[i],psattabr^[i]);
for i:=0 to 531 do read(ft,puratabl^[i],puratabb^[i],puratabr^[i]);
for i:=0 to 161 do read(ft,pneptabl^[i],pneptabb^[i],pneptabr^[i]);
for i:=0 to 603 do read(ft,pplutabl^[i],pplutabb^[i],pplutabr^[i]);
for i:=0 to 849 do read(ft,pmlattabl^[i]);
for i:=0 to 1561 do read(ft,pmlrtabl^[i],pmlrtabr^[i]);
for i:=1 to kx0 do read(ft,psx0^[i,1],psx0^[i,2],psx0^[i,3]);
for i:=1 to kx1 do read(ft,psx1^[i,1],psx1^[i,2],psx1^[i,3]);
for i:=1 to kx2 do read(ft,psx2^[i,1],psx2^[i,2],psx2^[i,3]);
for i:=1 to kx3 do read(ft,psx3^[i,1],psx3^[i,2],psx3^[i,3]);
for i:=1 to kx4 do read(ft,psx4^[i,1],psx4^[i,2],psx4^[i,3]);
for i:=1 to kx5 do read(ft,psx5^[i,1],psx5^[i,2],psx5^[i,3]);
for i:=1 to ky0 do read(ft,psy0^[i,1],psy0^[i,2],psy0^[i,3]);
for i:=1 to ky1 do read(ft,psy1^[i,1],psy1^[i,2],psy1^[i,3]);
for i:=1 to ky2 do read(ft,psy2^[i,1],psy2^[i,2],psy2^[i,3]);
for i:=1 to ky3 do read(ft,psy3^[i,1],psy3^[i,2],psy3^[i,3]);
for i:=1 to ky4 do read(ft,psy4^[i,1],psy4^[i,2],psy4^[i,3]);
for i:=1 to ky5 do read(ft,psy5^[i,1],psy5^[i,2],psy5^[i,3]);
for i:=1 to kz0 do read(ft,psz0^[i,1],psz0^[i,2],psz0^[i,3]);
for i:=1 to kz1 do read(ft,psz1^[i,1],psz1^[i,2],psz1^[i,3]);
for i:=1 to kz2 do read(ft,psz2^[i,1],psz2^[i,2],psz2^[i,3]);
for i:=1 to kz3 do read(ft,psz3^[i,1],psz3^[i,2],psz3^[i,3]);
for i:=1 to kz4 do read(ft,psz4^[i,1],psz4^[i,2],psz4^[i,3]);
for i:=1 to kz5 do read(ft,psz5^[i,1],psz5^[i,2],psz5^[i,3]);
close(ft);
END;

PROCEDURE pla_disposemem;
BEGIN
dispose(psx0); dispose(psx1); dispose(psx2); dispose(psx3); dispose(psx4);
dispose(psx5); dispose(psy0); dispose(psy1); dispose(psy2); dispose(psy3);
dispose(psy4); dispose(psy5); dispose(psz0); dispose(psz1); dispose(psz2);
dispose(psz3); dispose(psz4); dispose(psz5); dispose(pmertabl);
dispose(pmertabb); dispose(pmertabr); dispose(pventabl); dispose(pventabb);
dispose(pventabr); dispose(pmartabl); dispose(pmartabb); dispose(pmartabr);
dispose(pjuptabl); dispose(pjuptabb); dispose(pjuptabr); dispose(psattabl);
dispose(psattabb); dispose(psattabr); dispose(puratabl); dispose(puratabb);
dispose(puratabr); dispose(pneptabl); dispose(pneptabb); dispose(pneptabr);
dispose(pplutabl); dispose(pplutabb); dispose(pplutabr); dispose(pmlattabl);
dispose(pmlrtabl); dispose(pmlrtabr);
END;

FUNCTION mods3600(x: double): double;
BEGIN
if abs(x)<1.296e+6 then mods3600:=x
else begin
temp:=x-1.296e+6*int(x/1.296e+6);
if temp<0 then temp:=temp+1.296e+6;
mods3600:=temp;
end
END;

FUNCTION modl2pi(x: double): double;
BEGIN
if abs(x)<PI2 then temp:=x
else temp:=x-int(x/PI2)*PI2;
if temp<0 then temp:=temp+PI2;
modl2pi:=temp
END;

FUNCTION modb2pi(x: double): double;
BEGIN
if abs(x)<PI2 then modb2pi:=x
else modb2pi:=x-int(x/PI2)*PI2
END;

PROCEDURE mean_elements(j: double);
BEGIN
t:=(j-2451545.0)/36525.0;
t2:=t*t;
{mean longitudes of planets}
{Mercury}
x:=mods3600(538101628.6889819*t+908103.213);
x:=x+(6.39e-6*t-0.0192789)*t2;
args[0]:=RDA*x;
{Venus}
x:=mods3600(210664136.4335482*t+655127.236);
x:=x+(-6.27e-6*t+0.0059381)*t2;
args[1]:=RDA*x;
{Earth}
x:=mods3600(129597742.283429*t+361679.198);
x:=x+(-5.23e-6*t-2.04411e-2)*t2;
args[2]:=RDA*x;
{Mars}
x:=mods3600(68905077.493988*t+1279558.751);
x:=x+(-1.043e-5*t+0.0094264)*t2;
args[3]:=RDA*x;
{Jupiter}
x:=mods3600(10925660.377991*t+123665.420);
x:=x+((((-3.4e-10*t+5.91e-8)*t+4.667e-6)*t+5.706e-5)*t-3.060378e-1)*t2;
args[4]:=RDA*x;
{Saturn}
x:=mods3600(4399609.855372*t+180278.752);
x:=x+((((8.3e-10*t-1.452e-7)*t-1.1484e-5)*t-1.6618e-4)*t+7.561614e-1)*t2;
args[5]:=RDA*x;
{Uranus}
x:=mods3600(1542481.193933*t+1130597.971)+(0.00002156*t-0.0175083)*t2;
args[6]:=RDA*x;
{Neptune}
x:=mods3600(786550.320744*t+1095655.149)+(0.0021103-0.00000895*t)*t2;
args[7]:=RDA*x;
args[8]:=0.0;
{mean elongation of moon}
x:=mods3600(1.6029616009939659e+09*t+1.0722612202445078e+06);
x:=x+(((((-3.207663637426e-013*t+2.555243317839e-011)*t+2.560078201452e-009)*t
-3.702060118571e-005)*t+6.9492746836058421e-03)*t-6.7352202374457519e+00)*t2;
args[9]:=RDA*x;
{mean distance of moon from its ascending node}
x:=mods3600(1.7395272628437717e+09*t+3.3577951412884740e+05);
x:=x+(((((4.474984866301e-013*t+4.189032191814e-011)*t-2.790392351314e-009)*t
-2.165750777942e-006)*t-7.5311878482337989e-04)*t-1.3117809789650071e+01)*t2;
args[10]:=RDA*x;
{mean anomaly of sun}
x:=mods3600(1.2959658102304320e+08*t+1.2871027407441526e+06);
x:=x+((((((((1.62e-20*t-1.0390e-17)*t-3.83508e-15)*t+4.237343e-13)*t
+8.8555011e-11)*t-4.77258489e-8)*t-1.1297037031e-5)*t
+8.7473717367324703e-05)*t-5.5281306421783094e-01)*t2;
args[11]:=RDA*x;
{mean anomaly of moon}
x:=mods3600(1.7179159228846793e+09*t+4.8586817465825332e+05);
x:=x+(((((-1.755312760154e-012)*t+3.452144225877e-011*t-2.506365935364e-008)*t
-2.536291235258e-004)*t+5.2099641302735818e-02)*t+3.1501359071894147e+01)*t2;
args[12]:=RDA*x;
{mean longitude of moon}
x:=mods3600(1.7325643720442266e+09*t+7.8593980921052420e+05);
x:=x+(((((7.200592540556e-014*t+2.235210987108e-010)*t-1.024222633731e-008)*t
-6.073960534117e-005)*t+6.9017248528380490e-03)*t-5.6550460027471399e+00)*t2;
lp_equinox:=x;
args[13]:=RDA*x;
END;

PROCEDURE sscc(k: integer; arg: double; n: integer);
{calculates sine and cosine arrays for multiple angles}
BEGIN
asu:=sin(arg);
acu:=cos(arg);
ss[k][0]:=asu;
cc[k][0]:=acu;
asv:=2.0*asu*acu;
acv:=acu*acu-asu*asu;
ss[k][1]:=asv;
cc[k][1]:=acv;
for sci:=2 to n-1 do begin
s:=asu*acv+acu*asv;
acv:=acu*acv-asu*asv;
asv:=s;
ss[k][sci]:=asv;
cc[k][sci]:=acv;
end;
END;

PROCEDURE pos_mer (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[0,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*t)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=merargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=merargs[p];
inc(p);
cul:=pmertabl^[pl];
cub:=pmertabb^[pb];
cur:=pmertabr^[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+pmertabl^[pl];
cub:=cub*t+pmertabb^[pb];
cur:=cur*t+pmertabr^[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=merargs[p];
m:=merargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=merargs[p];
inc(p);
cul:=pmertabl^[pl];
sul:=pmertabl^[pl+1];
cub:=pmertabb^[pb];
sub:=pmertabb^[pb+1];
cur:=pmertabr^[pr];
sur:=pmertabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+pmertabl^[pl];
sul:=sul*t+pmertabl^[pl+1];
cub:=cub*t+pmertabb^[pb];
sub:=sub*t+pmertabb^[pb+1];
cur:=cur*t+pmertabr^[pr];
sur:=sur*t+pmertabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=merargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[0]*sr+distance[0];
END;

PROCEDURE pos_ven (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[1,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*t)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=venargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=venargs[p];
inc(p);
cul:=pventabl^[pl];
cub:=pventabb^[pb];
cur:=pventabr^[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+pventabl^[pl];
cub:=cub*t+pventabb^[pb];
cur:=cur*t+pventabr^[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=venargs[p];
m:=venargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=venargs[p];
inc(p);
cul:=pventabl^[pl];
sul:=pventabl^[pl+1];
cub:=pventabb^[pb];
sub:=pventabb^[pb+1];
cur:=pventabr^[pr];
sur:=pventabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+pventabl^[pl];
sul:=sul*t+pventabl^[pl+1];
cub:=cub*t+pventabb^[pb];
sub:=sub*t+pventabb^[pb+1];
cur:=cur*t+pventabr^[pr];
sur:=sur*t+pventabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=venargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[1]*sr+distance[1];
END;

PROCEDURE pos_mar (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[3,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*t)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=marargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=marargs[p];
inc(p);
cul:=pmartabl^[pl];
cub:=pmartabb^[pb];
cur:=pmartabr^[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+pmartabl^[pl];
cub:=cub*t+pmartabb^[pb];
cur:=cur*t+pmartabr^[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=marargs[p];
m:=marargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=marargs[p];
inc(p);
cul:=pmartabl^[pl];
sul:=pmartabl^[pl+1];
cub:=pmartabb^[pb];
sub:=pmartabb^[pb+1];
cur:=pmartabr^[pr];
sur:=pmartabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+pmartabl^[pl];
sul:=sul*t+pmartabl^[pl+1];
cub:=cub*t+pmartabb^[pb];
sub:=sub*t+pmartabb^[pb+1];
cur:=cur*t+pmartabr^[pr];
sur:=sur*t+pmartabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=marargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[2]*sr+distance[2];
END;

PROCEDURE pos_jup (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[4,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*t)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=jupargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=jupargs[p];
inc(p);
cul:=pjuptabl^[pl];
cub:=pjuptabb^[pb];
cur:=pjuptabr^[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+pjuptabl^[pl];
cub:=cub*t+pjuptabb^[pb];
cur:=cur*t+pjuptabr^[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=jupargs[p];
m:=jupargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=jupargs[p];
inc(p);
cul:=pjuptabl^[pl];
sul:=pjuptabl^[pl+1];
cub:=pjuptabb^[pb];
sub:=pjuptabb^[pb+1];
cur:=pjuptabr^[pr];
sur:=pjuptabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+pjuptabl^[pl];
sul:=sul*t+pjuptabl^[pl+1];
cub:=cub*t+pjuptabb^[pb];
sub:=sub*t+pjuptabb^[pb+1];
cur:=cur*t+pjuptabr^[pr];
sur:=sur*t+pjuptabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=jupargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[3]*sr+distance[3];
END;

PROCEDURE pos_sat (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[5,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*t)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=satargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=satargs[p];
inc(p);
cul:=psattabl^[pl];
cub:=psattabb^[pb];
cur:=psattabr^[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+psattabl^[pl];
cub:=cub*t+psattabb^[pb];
cur:=cur*t+psattabr^[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=satargs[p];
m:=satargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=satargs[p];
inc(p);
cul:=psattabl^[pl];
sul:=psattabl^[pl+1];
cub:=psattabb^[pb];
sub:=psattabb^[pb+1];
cur:=psattabr^[pr];
sur:=psattabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+psattabl^[pl];
sul:=sul*t+psattabl^[pl+1];
cub:=cub*t+psattabb^[pb];
sub:=sub*t+psattabb^[pb+1];
cur:=cur*t+psattabr^[pr];
sur:=sur*t+psattabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=satargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[4]*sr+distance[4];
END;

PROCEDURE pos_ura (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[6,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*t)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=uraargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=uraargs[p];
inc(p);
cul:=puratabl^[pl];
cub:=puratabb^[pb];
cur:=puratabr^[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+puratabl^[pl];
cub:=cub*t+puratabb^[pb];
cur:=cur*t+puratabr^[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=uraargs[p];
m:=uraargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=uraargs[p];
inc(p);
cul:=puratabl^[pl];
sul:=puratabl^[pl+1];
cub:=puratabb^[pb];
sub:=puratabb^[pb+1];
cur:=puratabr^[pr];
sur:=puratabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+puratabl^[pl];
sul:=sul*t+puratabl^[pl+1];
cub:=cub*t+puratabb^[pb];
sub:=sub*t+puratabb^[pb+1];
cur:=cur*t+puratabr^[pr];
sur:=sur*t+puratabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=uraargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[5]*sr+distance[5];
END;

PROCEDURE pos_nep (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[7,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*t)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=nepargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=nepargs[p];
inc(p);
cul:=pneptabl^[pl];
cub:=pneptabb^[pb];
cur:=pneptabr^[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+pneptabl^[pl];
cub:=cub*t+pneptabb^[pb];
cur:=cur*t+pneptabr^[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=nepargs[p];
m:=nepargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=nepargs[p];
inc(p);
cul:=pneptabl^[pl];
sul:=pneptabl^[pl+1];
cub:=pneptabb^[pb];
sub:=pneptabb^[pb+1];
cur:=pneptabr^[pr];
sur:=pneptabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+pneptabl^[pl];
sul:=sul*t+pneptabl^[pl+1];
cub:=cub*t+pneptabb^[pb];
sub:=sub*t+pneptabb^[pb+1];
cur:=cur*t+pneptabr^[pr];
sur:=sur*t+pneptabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=nepargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[6]*sr+distance[6];
END;

PROCEDURE pos_plu (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[8,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*t)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=pluargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=pluargs[p];
inc(p);
cul:=pplutabl^[pl];
cub:=pplutabb^[pb];
cur:=pplutabr^[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+pplutabl^[pl];
cub:=cub*t+pplutabb^[pb];
cur:=cur*t+pplutabr^[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=pluargs[p];
m:=pluargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=pluargs[p];
inc(p);
cul:=pplutabl^[pl];
sul:=pplutabl^[pl+1];
cub:=pplutabb^[pb];
sub:=pplutabb^[pb+1];
cur:=pplutabr^[pr];
sur:=pplutabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+pplutabl^[pl];
sul:=sul*t+pplutabl^[pl+1];
cub:=cub*t+pplutabb^[pb];
sub:=sub*t+pplutabb^[pb+1];
cur:=cur*t+pplutabr^[pr];
sur:=sur*t+pplutabr^[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=pluargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[7]*sr+distance[7];
END;

PROCEDURE pos_moo (j: double; var a,b,c: double);
BEGIN
mean_elements(j);
t:=(j-2451545.0)/3652500.0;
for i:=0 to 13 do begin
jp:=max_armonic_mlr[i];
if jp>0 then sscc(i,args[i],jp);
end;
p:=0;
pl:=0;
pr:=0;
sl:=0.0;
sr:=0.0;
np:=mlrargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=mlrargs[p];
inc(p);
cul:=pmlrtabl^[pl];
cur:=pmlrtabr^[pr];
inc(pl); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*t+pmlrtabl^[pl];
cur:=cur*t+pmlrtabr^[pr];
inc(pl); inc(pr);
end;
sl:=sl+cul;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=mlrargs[p];
m:=mlrargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=mlrargs[p];
inc(p);
cul:=pmlrtabl^[pl];
sul:=pmlrtabl^[pl+1];
cur:=pmlrtabr^[pr];
sur:=pmlrtabr^[pr+1];
inc(pl,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*t+pmlrtabl^[pl];
sul:=sul*t+pmlrtabl^[pl+1];
cur:=cur*t+pmlrtabr^[pr];
sur:=sur*t+pmlrtabr^[pr+1];
inc(pl,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=mlrargs[p];
inc(p);
end;
a:=sl/10000.0;
c:=sr/10000.0;
for i:=0 to 13 do begin
jp:=max_armonic_mlat[i];
if jp>0 then sscc(i,args[i],jp);
end;
p:=0;
pb:=0;
sb:=0.0;
np:=mlatargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=mlatargs[p];
inc(p);
cub:=pmlattabl^[pb];
inc(pb);
for ip:=0 to nt-1 do begin
cub:=cub*t+pmlattabl^[pb];
inc(pb);
end;
sb:=sb+cub;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=mlatargs[p];
m:=mlatargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=mlatargs[p];
inc(p);
cub:=pmlattabl^[pb];
sub:=pmlattabl^[pb+1];
inc(pb,2);
for ip:=0 to nt-1 do begin
cub:=cub*t+pmlattabl^[pb];
sub:=sub*t+pmlattabl^[pb+1];
inc(pb,2);
end;
sb:=sb+cub*cv+sub*sv;
end;
np:=mlatargs[p];
inc(p);
end;
b:=sb/10000.0;
x:=a;
x:=x+lp_equinox;
if x<-6.45e5 then x:=x+1.296e6;
if x>6.45e5 then x:=x-1.296e6;
a:=modl2pi(RDA*x);
b:=modb2pi(RDA*b);
x:=(1.0+RDA*c)*distance[8];
c:=x;
END;

PROCEDURE pos_ear (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/365250.0;
mx0:=0; mx1:=0; mx2:=0; mx3:=0; mx4:=0; mx5:=0;
my0:=0; my1:=0; my2:=0; my3:=0; my4:=0; my5:=0;
mz0:=0; mz1:=0; mz2:=0; mz3:=0; mz4:=0; mz5:=0;
for i:=1 to kx0 do mx0:=mx0+psx0^[i,1]*cos(psx0^[i,2]+psx0^[i,3]*t);
for i:=1 to kx1 do mx1:=mx1+psx1^[i,1]*cos(psx1^[i,2]+psx1^[i,3]*t);
for i:=1 to kx2 do mx2:=mx2+psx2^[i,1]*cos(psx2^[i,2]+psx2^[i,3]*t);
for i:=1 to kx3 do mx3:=mx3+psx3^[i,1]*cos(psx3^[i,2]+psx3^[i,3]*t);
for i:=1 to kx4 do mx4:=mx4+psx4^[i,1]*cos(psx4^[i,2]+psx4^[i,3]*t);
for i:=1 to kx5 do mx5:=mx5+psx5^[i,1]*cos(psx5^[i,2]+psx5^[i,3]*t);
for i:=1 to ky0 do my0:=my0+psy0^[i,1]*cos(psy0^[i,2]+psy0^[i,3]*t);
for i:=1 to ky1 do my1:=my1+psy1^[i,1]*cos(psy1^[i,2]+psy1^[i,3]*t);
for i:=1 to ky2 do my2:=my2+psy2^[i,1]*cos(psy2^[i,2]+psy2^[i,3]*t);
for i:=1 to ky3 do my3:=my3+psy3^[i,1]*cos(psy3^[i,2]+psy3^[i,3]*t);
for i:=1 to ky4 do my4:=my4+psy4^[i,1]*cos(psy4^[i,2]+psy4^[i,3]*t);
for i:=1 to ky5 do my5:=my5+psy5^[i,1]*cos(psy5^[i,2]+psy5^[i,3]*t);
for i:=1 to kz0 do mz0:=mz0+psz0^[i,1]*cos(psz0^[i,2]+psz0^[i,3]*t);
for i:=1 to kz1 do mz1:=mz1+psz1^[i,1]*cos(psz1^[i,2]+psz1^[i,3]*t);
for i:=1 to kz2 do mz2:=mz2+psz2^[i,1]*cos(psz2^[i,2]+psz2^[i,3]*t);
for i:=1 to kz3 do mz3:=mz3+psz3^[i,1]*cos(psz3^[i,2]+psz3^[i,3]*t);
for i:=1 to kz4 do mz4:=mz4+psz4^[i,1]*cos(psz4^[i,2]+psz4^[i,3]*t);
for i:=1 to kz5 do mz5:=mz5+psz5^[i,1]*cos(psz5^[i,2]+psz5^[i,3]*t);
mx0:=mx0+((((mx5*t+mx4)*t+mx3)*t+mx2)*t+mx1)*t;
my0:=my0+((((my5*t+my4)*t+my3)*t+my2)*t+my1)*t;
c:=mz0+((((mz5*t+mz4)*t+mz3)*t+mz2)*t+mz1)*t;
a:=modl2pi(mx0);
b:=modb2pi(my0);
END;

PROCEDURE vel_ear (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/365250.0;
mx0:=0; mx1:=0; mx2:=0; mx3:=0; mx4:=0; mx5:=0;
my0:=0; my1:=0; my2:=0; my3:=0; my4:=0; my5:=0;
mz0:=0; mz1:=0; mz2:=0; mz3:=0; mz4:=0; mz5:=0;
for i:=1 to kx0 do mx0:=mx0-psx0^[i,1]*psx0^[i,3]*sin(psx0^[i,2]+psx0^[i,3]*t);
for i:=1 to kx1 do mx1:=mx1-psx1^[i,1]*psx1^[i,3]*t*sin(psx1^[i,2]+psx1^[i,3]*t)
+psx1^[i,1]*cos(psx1^[i,2]+psx1^[i,3]*t);
for i:=1 to kx2 do mx2:=mx2-psx2^[i,1]*psx2^[i,3]*t*sin(psx2^[i,2]+psx2^[i,3]*t)
+2*psx2^[i,1]*cos(psx2^[i,2]+psx2^[i,3]*t);
for i:=1 to kx3 do mx3:=mx3-psx3^[i,1]*psx3^[i,3]*t*sin(psx3^[i,2]+psx3^[i,3]*t)
+3*psx3^[i,1]*cos(psx3^[i,2]+psx3^[i,3]*t);
for i:=1 to kx4 do mx4:=mx4-psx4^[i,1]*psx4^[i,3]*t*sin(psx4^[i,2]+psx4^[i,3]*t)
+4*psx4^[i,1]*cos(psx4^[i,2]+psx4^[i,3]*t);
for i:=1 to kx5 do mx5:=mx5-psx5^[i,1]*psx5^[i,3]*t*sin(psx5^[i,2]+psx5^[i,3]*t)
+5*psx5^[i,1]*cos(psx5^[i,2]+psx5^[i,3]*t);
for i:=1 to ky0 do my0:=my0-psy0^[i,1]*psy0^[i,3]*sin(psy0^[i,2]+psy0^[i,3]*t);
for i:=1 to ky1 do my1:=my1-psy1^[i,1]*psy1^[i,3]*t*sin(psy1^[i,2]+psy1^[i,3]*t)
+psy1^[i,1]*cos(psy1^[i,2]+psy1^[i,3]*t);
for i:=1 to ky2 do my2:=my2-psy2^[i,1]*psy2^[i,3]*t*sin(psy2^[i,2]+psy2^[i,3]*t)
+2*psy2^[i,1]*cos(psy2^[i,2]+psy2^[i,3]*t);
for i:=1 to ky3 do my3:=my3-psy3^[i,1]*psy3^[i,3]*t*sin(psy3^[i,2]+psy3^[i,3]*t)
+3*psy3^[i,1]*cos(psy3^[i,2]+psy3^[i,3]*t);
for i:=1 to ky4 do my4:=my4-psy4^[i,1]*psy4^[i,3]*t*sin(psy4^[i,2]+psy4^[i,3]*t)
+4*psy4^[i,1]*cos(psy4^[i,2]+psy4^[i,3]*t);
for i:=1 to ky5 do my5:=my5-psy5^[i,1]*psy5^[i,3]*t*sin(psy5^[i,2]+psy5^[i,3]*t)
+5*psy5^[i,1]*cos(psy5^[i,2]+psy5^[i,3]*t);
for i:=1 to kz0 do mz0:=mz0-psz0^[i,1]*psz0^[i,3]*sin(psz0^[i,2]+psz0^[i,3]*t);
for i:=1 to kz1 do mz1:=mz1-psz1^[i,1]*psz1^[i,3]*t*sin(psz1^[i,2]+psz1^[i,3]*t)
+psz1^[i,1]*cos(psz1^[i,2]+psz1^[i,3]*t);
for i:=1 to kz2 do mz2:=mz2-psz2^[i,1]*psz2^[i,3]*t*sin(psz2^[i,2]+psz2^[i,3]*t)
+2*psz2^[i,1]*cos(psz2^[i,2]+psz2^[i,3]*t);
for i:=1 to kz3 do mz3:=mz3-psz3^[i,1]*psz3^[i,3]*t*sin(psz3^[i,2]+psz3^[i,3]*t)
+3*psz3^[i,1]*cos(psz3^[i,2]+psz3^[i,3]*t);
for i:=1 to kz4 do mz4:=mz4-psz4^[i,1]*psz4^[i,3]*t*sin(psz4^[i,2]+psz4^[i,3]*t)
+4*psz4^[i,1]*cos(psz4^[i,2]+psz4^[i,3]*t);
for i:=1 to kz5 do mz5:=mz5-psz5^[i,1]*psz5^[i,3]*t*sin(psz5^[i,2]+psz5^[i,3]*t)
+5*psz5^[i,1]*cos(psz5^[i,2]+psz5^[i,3]*t);
a:=(mx0+mx1+(((mx5*t+mx4)*t+mx3)*t+mx2)*t)/365250.0;
b:=(my0+my1+(((my5*t+my4)*t+my3)*t+my2)*t)/365250.0;
c:=(mz0+mz1+(((mz5*t+mz4)*t+mz3)*t+mz2)*t)/365250.0;
END;

END.
